@@ -30,6 +30,7 @@
 #include "StelFader.hpp"
 #include "StelProjectorType.hpp"
 
+class StelPainter;
 
 //! @class Nova
 //! A Nova object represents one nova on the sky.
@@ -52,7 +53,6 @@ public:
 	{
 		return "Nova";
 	}
-	virtual float getSelectPriority(const StelCore* core) const;
 
 	//! Get an HTML string to describe the object
 	//! @param core A pointer to the core
@@ -63,7 +63,7 @@ public:
 	{
 		return XYZ;
 	}
-	virtual float getVMagnitude(const StelCore* core, bool withExtinction=false) const;
+	virtual float getVMagnitude(const StelCore* core) const;
 	virtual double getAngularSize(const StelCore* core) const;
 	virtual QString getNameI18n(void) const;
 	virtual QString getEnglishName(void) const;
@@ -76,7 +76,7 @@ private:
 
 	Vec3d XYZ;                         // holds J2000 position
 
-	void draw(StelCore* core, class StelRenderer* renderer, StelProjectorP projector);
+	void draw(StelCore* core, StelPainter* painter);
 
 	// Nova
 	QString designation;		//! The ID of the nova
