@@ -16,16 +16,20 @@
  * Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA  02110-1335, USA.
  */
 
+#include "config.h"
+
 #include "Pulsar.hpp"
 #include "Pulsars.hpp"
 #include "StelObject.hpp"
+#include "StelPainter.hpp"
 #include "StelApp.hpp"
 #include "StelCore.hpp"
+#include "StelTexture.hpp"
 #include "StelUtils.hpp"
 #include "StelTranslator.hpp"
 #include "StelModuleMgr.hpp"
 #include "StelSkyDrawer.hpp"
-#include "renderer/StelRenderer.hpp"
+#include "StelProjector.hpp"
 
 #include <QTextStream>
 #include <QDebug>
@@ -36,8 +40,33 @@
 
 #define PSR_INERTIA 1.0e45 /* Typical moment of inertia for a pulsar */
 
+StelTextureSP Pulsar::markerTexture;
+
+bool Pulsar::distributionMode = false;
+bool Pulsar::glitchFlag = false;
+Vec3f Pulsar::markerColor = Vec3f(0.4f,0.5f,1.0f);
+Vec3f Pulsar::glitchColor = Vec3f(0.2f,0.3f,1.0f);
+
 Pulsar::Pulsar(const QVariantMap& map)
-		: initialized(false)
+		: initialized(false),
+		  designation(""),
+		  RA(0.),
+		  DE(0.),
+		  parallax(0.),
+		  period(0.),
+		  frequency(0.),
+		  pfrequency(0.),
+		  pderivative(0.),
+		  dmeasure(0.),
+		  bperiod(0.),
+		  eccentricity(0.),
+		  w50(0.),
+		  s400(0.),
+		  s600(0.),
+		  s1400(0.),
+		  distance(0.),
+		  glitch(-1),
+		  notes("")
 {
 	// return initialized if the mandatory fields are not present
 	if (!map.contains("designation"))
@@ -59,6 +88,7 @@ Pulsar::Pulsar(const QVariantMap& map)
 	s600 = map.value("s600").toFloat();
 	s1400 = map.value("s1400").toFloat();
 	distance = map.value("distance").toFloat();
+	glitch = map.value("glitch").toInt();
 	notes = map.value("notes").toString();
 
 	// If barycentric period not set then calculate it
@@ -99,6 +129,7 @@ QVariantMap Pulsar::getMap(void)
 	map["s600"] = s600;
 	map["s1400"] = s1400;
 	map["distance"] = distance;
+	map["glitch"] = glitch;
 	map["notes"] = notes;
 
 	return map;
@@ -106,8 +137,7 @@ QVariantMap Pulsar::getMap(void)
 
 float Pulsar::getSelectPriority(const StelCore* core) const
 {
-	//Same as StarWrapper::getSelectPriority()
-        return getVMagnitude(core, false);
+	return StelObject::getSelectPriority(core)-2.f;
 }
 
 QString Pulsar::getInfoString(const StelCore* core, const InfoStringGroup& flags) const
@@ -120,15 +150,29 @@ QString Pulsar::getInfoString(const StelCore* core, const InfoStringGroup& flags
 		oss << "<h2>" << designation << "</h2>";
 	}
 
-	if (flags&Extra1)
+	if (flags&ObjectType)
 	{
-		oss << q_("Type: <b>%1</b>").arg(q_("pulsar")) << "<br />";
+
+		if (glitch==0)
+			oss << q_("Type: <b>%1</b>").arg(q_("pulsar")) << "<br />";
+		else
+		{
+			QString sglitch;
+			if (glitch==1)
+				sglitch = q_("has one registered glitch");
+			else
+			{
+				// TRANSLATORS: Full phrase is "Has X registered glitches", where X is number
+				sglitch = q_("has %1 registered glitches").arg(glitch);
+			}
+			oss << q_("Type: <b>%1</b> (%2)").arg(q_("pulsar with glitches")).arg(sglitch) << "<br />";
+		}
 	}
 
 	// Ra/Dec etc.
 	oss << getPositionInfoString(core, flags);
 
-	if (flags&Extra1)
+	if (flags&Extra)
 	{
 		if (period>0)
 		{
@@ -212,7 +256,7 @@ QString Pulsar::getInfoString(const StelCore* core, const InfoStringGroup& flags
 			       .arg(QString::number(s1400, 'f', 2))
 			       // TRANSLATORS: mJy is milliJansky(10-26W/m2/Hz)
 			       .arg(q_("mJy")) << "<br>";
-		}
+		}		
 		if (notes.length()>0)
 		{
 			oss << "<br>" << q_("Notes: %1").arg(getPulsarTypeInfoString(notes)) << "<br>";
@@ -225,32 +269,30 @@ QString Pulsar::getInfoString(const StelCore* core, const InfoStringGroup& flags
 
 Vec3f Pulsar::getInfoColor(void) const
 {
-	return StelApp::getInstance().getVisionModeNight() ? Vec3f(0.6, 0.0, 0.0) : Vec3f(1.0, 1.0, 1.0);
+	return Vec3f(1.0, 1.0, 1.0);
 }
 
-float Pulsar::getVMagnitude(const StelCore* core, bool withExtinction) const
+float Pulsar::getVMagnitude(const StelCore* core) const
 {
-	float extinctionMag=0.0; // track magnitude loss
-	if (withExtinction && core->getSkyDrawer()->getFlagHasAtmosphere())
-	{
-	    Vec3d altAz=getAltAzPosApparent(core);
-	    altAz.normalize();
-	    core->getSkyDrawer()->getExtinction().forward(&altAz[2], &extinctionMag);
-	}
-
+	Q_UNUSED(core);
 	// Calculate fake visual magnitude as function by distance - minimal magnitude is 6
 	float vmag = distance + 6.f;
 
-	if (GETSTELMODULE(Pulsars)->getDisplayMode())
+	if (distributionMode)
 	{
 		return 3.f;
 	}
 	else
 	{
-		return vmag + extinctionMag;
+		return vmag;
 	}
 }
 
+float Pulsar::getVMagnitudeWithExtinction(const StelCore *core) const
+{
+	return getVMagnitude(core);
+}
+
 double Pulsar::getEdot(double p0, double p1) const
 {
 	if (p0>0 && p1!=0)
@@ -330,39 +372,36 @@ void Pulsar::update(double deltaTime)
 	labelsFader.update((int)(deltaTime*1000));
 }
 
-void Pulsar::draw(StelCore* core, StelRenderer* renderer, StelProjectorP projector,
-                  StelTextureNew* markerTexture)
+void Pulsar::draw(StelCore* core, StelPainter *painter)
 {
-	StelSkyDrawer* sd = core->getSkyDrawer();	
+	StelSkyDrawer* sd = core->getSkyDrawer();
+	double mag = getVMagnitudeWithExtinction(core);
+	StelUtils::spheToRect(RA, DE, XYZ);
 
-	Vec3f color = Vec3f(0.4f,0.5f,1.2f);
-	if (StelApp::getInstance().getVisionModeNight())
-		color = StelUtils::getNightColor(color);
+	Vec3d win;
+	// Check visibility of pulsar
+	if (!(painter->getProjector()->projectCheck(XYZ, win)))
+		return;
 
-	double mag = getVMagnitude(core, true);
+	glEnable(GL_BLEND);
+	glBlendFunc(GL_ONE, GL_ONE);
+	if (glitch>0 && glitchFlag)
+		painter->setColor(glitchColor[0], glitchColor[1], glitchColor[2], 1);
+	else
+		painter->setColor(markerColor[0], markerColor[1], markerColor[2], 1);
+	float mlimit = sd->getLimitMagnitude();
 
-	StelUtils::spheToRect(RA, DE, XYZ);			
-	renderer->setBlendMode(BlendMode_Add);
-	renderer->setGlobalColor(color[0], color[1], color[2]);
+	if (mag <= mlimit)
+	{		
+		Pulsar::markerTexture->bind();
+		float size = getAngularSize(NULL)*M_PI/180.*painter->getProjector()->getPixelPerRadAtCenter();
+		float shift = 5.f + size/1.6f;		
 
-	if (mag <= sd->getLimitMagnitude())
-	{
-		markerTexture->bind();
-		const float size = getAngularSize(NULL)*M_PI/180.*projector->getPixelPerRadAtCenter();
-		const float shift = 5.f + size/1.6f;
-		if (labelsFader.getInterstate()<=0.f)
+		painter->drawSprite2dMode(XYZ, distributionMode ? 4.f : 5.f);
+
+		if (labelsFader.getInterstate()<=0.f && !distributionMode && (mag+2.f)<mlimit)
 		{
-			Vec3d win;
-			if(!projector->project(XYZ, win)){return;}
-			if (GETSTELMODULE(Pulsars)->getDisplayMode())
-			{
-				renderer->drawTexturedRect(win[0] - 4, win[1] - 4, 8, 8);
-			}
-			else
-			{
-				renderer->drawTexturedRect(win[0] - 5, win[1] - 5, 10, 10);
-				renderer->drawText(TextParams(XYZ, projector, designation).shift(shift, shift).useGravity());
-			}
+			painter->drawText(XYZ, designation, 0, shift, shift, false);
 		}
 	}
 }
