@@ -101,7 +101,7 @@ Pulsars::Pulsars()
 	setObjectName("Pulsars");
 	configDialog = new PulsarsDialog();
 	conf = StelApp::getInstance().getSettings();
-	font.setPixelSize(conf->value("gui/base_font_size", 13).toInt());
+	font.setPixelSize(StelApp::getInstance().getBaseFontSize());
 }
 
 /*
