@@ -93,6 +93,11 @@ void SatellitesDialog::createDialogContent()
 	        this, SLOT(retranslate()));
 	Satellites* plugin = GETSTELMODULE(Satellites);
 
+	//Kinetic scrolling for tablet pc and pc
+	QList<QWidget *> addscroll;
+	addscroll << ui->satellitesList << ui->sourceList << ui->aboutTextBrowser;
+	installKineticScrolling(addscroll);
+
 	// Settings tab / updates group
 	// These controls are refreshed by updateSettingsPage(), which in
 	// turn is triggered by setting any of these values. Because 
