@@ -145,7 +145,10 @@ QString Supernova::getInfoString(const StelCore* core, const InfoStringGroup& fl
 		oss << q_("Type of supernova: %1").arg(sntype) << "<br>";
 		oss << q_("Maximum brightness: %1").arg(getMaxBrightnessDate(peakJD)) << "<br>";
 		if (distance>0)
-			oss << q_("Distance: %1 Light Years").arg(distance*1000) << "<br>";
+		{
+			//TRANSLATORS: Unit of measure for distance - Light Years
+			oss << q_("Distance: %1 ly").arg(distance*1000) << "<br>";
+		}
 	}
 
 	postProcessInfoString(str, flags);
