@@ -19,6 +19,8 @@
 #ifndef _SUPERNOVA_HPP_
 #define _SUPERNOVA_HPP_ 1
 
+#include "config.h"
+
 #include <QVariant>
 #include <QString>
 #include <QStringList>
@@ -27,9 +29,10 @@
 #include <QDateTime>
 
 #include "StelObject.hpp"
+#include "StelTextureTypes.hpp"
 #include "StelFader.hpp"
-#include "StelProjectorType.hpp"
 
+class StelPainter;
 
 //! @class Supernova
 //! A Supernova object represents one supernova on the sky.
@@ -52,7 +55,6 @@ public:
 	{
 		return "Supernova";
 	}
-	virtual float getSelectPriority(const StelCore* core) const;
 
 	//! Get an HTML string to describe the object
 	//! @param core A pointer to the core
@@ -63,7 +65,7 @@ public:
 	{
 		return XYZ;
 	}
-	virtual float getVMagnitude(const StelCore* core, bool withExtinction=false) const;
+	virtual float getVMagnitude(const StelCore* core) const;
 	virtual double getAngularSize(const StelCore* core) const;
 	virtual QString getNameI18n(void) const;
 	virtual QString getEnglishName(void) const;
@@ -75,7 +77,9 @@ private:
 
 	Vec3d XYZ;                         // holds J2000 position
 
-	void draw(StelCore* core, class StelRenderer* renderer, StelProjectorP projector);
+	static StelTextureSP hintTexture;
+
+	void draw(StelCore* core, StelPainter& painter);
 
 	// Supernova
 	QString designation;               //! The ID of the supernova
