@@ -25,10 +25,10 @@ Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA  02110-1335, USA.
 #ifndef _SOCKET_HPP_
 #define _SOCKET_HPP_
 
+#include "config.h"
 #include <QtGlobal>
 
-#ifdef Q_OS_WIN32
-
+#ifdef Q_OS_WIN
 #include <winsock2.h>
 #include <fcntl.h>
 
