@@ -54,7 +54,8 @@ void CLIProcessor::parseCLIArgsPreConfig(const QStringList& argList)
 		          << "--config-file (or -c)   : Use an alternative name for the config file\n"
 		          << "--user-dir (or -u)      : Use an alternative user data directory\n"
 			  //<< "--safe-mode (or -s)     : Disable GL shaders and use older GL engine\n"
-			  //<< "                          Try this is you have graphics problems\n"
+			  << "--dump-opengl-details (or -d) : dump information about OpenGL support to logfile\n"
+			  << "                          Try this is you have graphics problems\n"
 		          << "--full-screen (or -f)   : With argument \"yes\" or \"no\" over-rides\n"
 		          << "                          the full screen setting in the config file\n"
 		          << "--screenshot-dir        : Specify directory to save screenshots\n"
@@ -120,6 +121,8 @@ void CLIProcessor::parseCLIArgsPostConfig(const QStringList& argList, QSettings*
 	QString projectionType, screenshotDir, multiresImage, startupScript;
 	try
 	{
+		bool dumpOpenGLDetails = argsGetOption(argList, "-d", "--dump-opengl-details");
+		qApp->setProperty("dump_OpenGL_details", dumpOpenGLDetails);
 		fullScreen = argsGetYesNoOption(argList, "-f", "--full-screen", -1);
 		landscapeId = argsGetOptionWithArg(argList, "", "--landscape", "").toString();
 		homePlanet = argsGetOptionWithArg(argList, "", "--home-planet", "").toString();
