@@ -17,13 +17,12 @@
  * Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA  02110-1335, USA.
  */
 
-#include <QFile>
-
-#include "glues.h"
-
+#include "StelUtils.hpp"
 #include "OctahedronPolygon.hpp"
 #include "StelSphereGeometry.hpp"
-#include "StelUtils.hpp"
+#include "glues.h"
+
+#include <QFile>
 
 const Vec3d OctahedronPolygon::sideDirections[] = {	Vec3d(1,1,1), Vec3d(1,1,-1),Vec3d(-1,1,1),Vec3d(-1,1,-1),
 	Vec3d(1,-1,1),Vec3d(1,-1,-1),Vec3d(-1,-1,1),Vec3d(-1,-1,-1)};
@@ -94,7 +93,7 @@ QString SubContour::toJSON() const
 	return res;
 };
 
-OctahedronPolygon::OctahedronPolygon(const QVector<Vec3d>& contour) 
+OctahedronPolygon::OctahedronPolygon(const QVector<Vec3d>& contour) : fillCachedVertexArray(StelVertexArray::Triangles), outlineCachedVertexArray(StelVertexArray::Lines)
 {
 	sides.resize(8);
 	appendSubContour(SubContour(contour));
@@ -102,7 +101,7 @@ OctahedronPolygon::OctahedronPolygon(const QVector<Vec3d>& contour)
 	updateVertexArray();
 }
 
-OctahedronPolygon::OctahedronPolygon(const QVector<QVector<Vec3d> >& contours) 
+OctahedronPolygon::OctahedronPolygon(const QVector<QVector<Vec3d> >& contours) : fillCachedVertexArray(StelVertexArray::Triangles), outlineCachedVertexArray(StelVertexArray::Lines)
 {
 	sides.resize(8);
 	foreach (const QVector<Vec3d>& contour, contours)
@@ -120,7 +119,7 @@ OctahedronPolygon::OctahedronPolygon(const SubContour& initContour)
 }
 
 
-OctahedronPolygon::OctahedronPolygon(const QList<OctahedronPolygon>& octs) 
+OctahedronPolygon::OctahedronPolygon(const QList<OctahedronPolygon>& octs) : fillCachedVertexArray(StelVertexArray::Triangles), outlineCachedVertexArray(StelVertexArray::Lines)
 {
 	sides.resize(8);
 	foreach (const OctahedronPolygon& oct, octs)
@@ -235,7 +234,8 @@ double OctahedronPolygon::getArea() const
 	// Use Girard's theorem for each subtriangles
 	double area = 0.;
 	Vec3d v1, v2, v3;
-	const QVector<Vec3d>& trianglesArray = fillVertices();
+	const QVector<Vec3d>& trianglesArray = getFillVertexArray().vertex;
+	Q_ASSERT(getFillVertexArray().primitiveType==StelVertexArray::Triangles);
 	for (int i=0;i<trianglesArray.size()/3;++i)
 	{
 		area += OctahedronPolygon::sphericalTriangleArea(trianglesArray.at(i*3), trianglesArray.at(i*3+1), trianglesArray.at(i*3+2));
@@ -246,7 +246,8 @@ double OctahedronPolygon::getArea() const
 // Return a point located inside the polygon. Actually, inside the first triangle in this case.
 Vec3d OctahedronPolygon::getPointInside() const
 {
-	const QVector<Vec3d>& trianglesArray = fillVertices();
+	const QVector<Vec3d>& trianglesArray = getFillVertexArray().vertex;
+	Q_ASSERT(getFillVertexArray().primitiveType==StelVertexArray::Triangles);
 	Q_ASSERT(!trianglesArray.isEmpty());
 	Vec3d res(trianglesArray[0]);
 	res+=trianglesArray[1];
@@ -319,7 +320,7 @@ struct OctTessTrianglesCallbackData
 
 void errorCallback(GLenum errno)
 {
-	qWarning() << "Tesselator error:" << QString::fromAscii((char*)gluesErrorString(errno));
+	qWarning() << "Tesselator error:" << QString::fromLatin1((char*)gluesErrorString(errno));
 	Q_ASSERT(0);
 }
 
@@ -376,8 +377,8 @@ inline void unprojectOctahedron(Vec3d& v, const Vec3d& sideDirection)
 void OctahedronPolygon::updateVertexArray()
 {
 	Q_ASSERT(sides.size()==8);
-	fillCachedVertexArray.clear();
-	outlineCachedVertexArray.clear();
+	fillCachedVertexArray.vertex.clear();
+	outlineCachedVertexArray.vertex.clear();
 
 	Q_ASSERT(sides.size()==8);
 	// Use GLUES tesselation functions to transform the polygon into a list of triangles
@@ -407,12 +408,12 @@ void OctahedronPolygon::updateVertexArray()
 			isTriangleConvexPositive2D(res.at(j+2), res.at(j+1), res.at(j)) :
 			isTriangleConvexPositive2D(res.at(j), res.at(j+1), res.at(j+2))))
 			{
-				fillCachedVertexArray += res.at(j);
-				unprojectOctahedron(fillCachedVertexArray.last(), sideDirection);
-				fillCachedVertexArray += res.at(j+1);
-				unprojectOctahedron(fillCachedVertexArray.last(), sideDirection);
-				fillCachedVertexArray += res.at(j+2);
-				unprojectOctahedron(fillCachedVertexArray.last(), sideDirection);
+				fillCachedVertexArray.vertex+=res.at(j);
+				unprojectOctahedron(fillCachedVertexArray.vertex.last(), sideDirection);
+				fillCachedVertexArray.vertex+=res.at(j+1);
+				unprojectOctahedron(fillCachedVertexArray.vertex.last(), sideDirection);
+				fillCachedVertexArray.vertex+=res.at(j+2);
+				unprojectOctahedron(fillCachedVertexArray.vertex.last(), sideDirection);
 			}
 			else
 			{
@@ -432,10 +433,10 @@ void OctahedronPolygon::updateVertexArray()
 			{
 				if (previous.edgeFlag || c.at(j+1).edgeFlag)
 				{
-					outlineCachedVertexArray.append(previous.vertex);
+					outlineCachedVertexArray.vertex.append(previous.vertex);
 					previous=c.at(j+1);
 					unprojectOctahedron(previous.vertex, sideDirection);
-					outlineCachedVertexArray.append(previous.vertex);
+					outlineCachedVertexArray.vertex.append(previous.vertex);
 				}
 				else
 				{
@@ -446,9 +447,9 @@ void OctahedronPolygon::updateVertexArray()
 			// Last point connects with first point
 			if (previous.edgeFlag || c.first().edgeFlag)
 			{
-				outlineCachedVertexArray.append(previous.vertex);
-				outlineCachedVertexArray.append(c.first().vertex);
-				unprojectOctahedron(outlineCachedVertexArray.last(), sideDirection);
+				outlineCachedVertexArray.vertex.append(previous.vertex);
+				outlineCachedVertexArray.vertex.append(c.first().vertex);
+				unprojectOctahedron(outlineCachedVertexArray.vertex.last(), sideDirection);
 			}
 		}
 	}
@@ -459,15 +460,15 @@ void OctahedronPolygon::updateVertexArray()
 	// Check that all triangles are properly oriented
 	QVector<Vec3d> c;
 	c.resize(3);
-	for (int j=0;j<fillCachedVertexArray.size()/3;++j)
+	for (int j=0;j<fillCachedVertexArray.vertex.size()/3;++j)
 	{
-		c[0]=fillCachedVertexArray.at(j*3);
-		c[1]=fillCachedVertexArray.at(j*3+1);
-		c[2]=fillCachedVertexArray.at(j*3+2);
+		c[0]=fillCachedVertexArray.vertex.at(j*3);
+		c[1]=fillCachedVertexArray.vertex.at(j*3+1);
+		c[2]=fillCachedVertexArray.vertex.at(j*3+2);
 		Q_ASSERT(SphericalConvexPolygon::checkValidContour(c));
 	}
 #else
-	// If I don't let this like that, the behaviour will fail in Release mode!!!!
+	// If I don't let this like that, the bahaviour will fail in Release mode!!!!
 	// It is either a bug in GCC either a memory problem which appears only when optimizations are activated.
 	QVector<Vec3d> c;
 	c.resize(3);
@@ -640,11 +641,11 @@ bool OctahedronPolygon::contains(const Vec3d& p) const
 {
 	if (sides[getSideNumber(p)].isEmpty())
 		return false;
-	for (int i=0;i<fillCachedVertexArray.size()/3;++i)
+	for (int i=0;i<fillCachedVertexArray.vertex.size()/3;++i)
 	{
-		if (sideHalfSpaceContains(fillCachedVertexArray.at(i*3+1), fillCachedVertexArray.at(i*3), p) &&
-			sideHalfSpaceContains(fillCachedVertexArray.at(i*3+2), fillCachedVertexArray.at(i*3+1), p) &&
-			sideHalfSpaceContains(fillCachedVertexArray.at(i*3), fillCachedVertexArray.at(i*3+2), p))
+		if (sideHalfSpaceContains(fillCachedVertexArray.vertex.at(i*3+1), fillCachedVertexArray.vertex.at(i*3), p) &&
+			sideHalfSpaceContains(fillCachedVertexArray.vertex.at(i*3+2), fillCachedVertexArray.vertex.at(i*3+1), p) &&
+			sideHalfSpaceContains(fillCachedVertexArray.vertex.at(i*3), fillCachedVertexArray.vertex.at(i*3+2), p))
 			return true;
 	}
 	return false;
@@ -808,7 +809,7 @@ void OctahedronPolygon::splitContourByPlan(int onLine, const SubContour& inputCo
 
 void OctahedronPolygon::computeBoundingCap()
 {
-	const QVector<Vec3d>& trianglesArray = outlineCachedVertexArray;
+	const QVector<Vec3d>& trianglesArray = outlineCachedVertexArray.vertex;
 	if (trianglesArray.isEmpty())
 	{
 		capN.set(1,0,0);
