@@ -20,11 +20,14 @@
 #ifndef _OCTAHEDRON_REGION_HPP_
 #define _OCTAHEDRON_REGION_HPP_
 
+#include "config.h"
+
+#include "StelVertexArray.hpp"
+#include "VecMath.hpp"
+
 #include <QVector>
 #include <QDebug>
 #include <QVarLengthArray>
-#include "VecMath.hpp"
-
 
 //! @struct EdgeVertex
 //! Describe a vertex composing polygon contours, and whether it belong to an edge or not.
@@ -55,21 +58,17 @@ public:
 	QString toJSON() const;
 };
 
-//! @class OctahedronContour
+//! @class OctahedronPolygon
 //! Manage a non-convex polygon which can extends on more than 180 deg.
-//! The contours defining the polygon are split and projected on the 8 sides of an Octahedron to enable 2D geometry
+//! The contours defining the polygon are splitted and projected on the 8 sides of an Octahedron to enable 2D geometry
 //! algorithms to be used.
 class OctahedronPolygon
 {
 public:
-	OctahedronPolygon() 
-		: capN(1,0,0)
-		, capD(-2.)
-	{
-		sides.resize(8);
-	}
+	OctahedronPolygon() : fillCachedVertexArray(StelVertexArray::Triangles), outlineCachedVertexArray(StelVertexArray::Lines), capN(1,0,0), capD(-2.)
+	{sides.resize(8);}
 
-	//! Create the OctahedronContour by splitting the passed SubContour on the 8 sides of the octahedron.
+	//! Create the OctahedronPolygon by splitting the passed SubContour on the 8 sides of the octahedron.
 	OctahedronPolygon(const SubContour& subContour);
 	OctahedronPolygon(const QVector<QVector<Vec3d> >& contours);
 	OctahedronPolygon(const QVector<Vec3d>& contour);
@@ -79,13 +78,17 @@ public:
 
 	Vec3d getPointInside() const;
 
+	//! Returns the list of triangles resulting from tesselating the contours.
+	StelVertexArray getFillVertexArray() const {return fillCachedVertexArray;}
+	StelVertexArray getOutlineVertexArray() const {return outlineCachedVertexArray;}
+
 	void getBoundingCap(Vec3d& v, double& d) const {v=capN; d=capD;}
 
-	//! Set this OctahedronContourOctahedronPolygonion of itself with the given OctahedronContour.
+	//! Set this OctahedronPolygon as the intersection of itself with the given OctahedronPolygon.
 	void inPlaceIntersection(const OctahedronPolygon& mpoly);
-	//! Set this OctahedronContour as the union of itself with the given OctahedronContour.
+	//! Set this OctahedronPolygon as the union of itself with the given OctahedronPolygon.
 	void inPlaceUnion(const OctahedronPolygon& mpoly);
-	//! Set this OctahedronContour as the subtraction of itself with the given OctahedronContour.
+	//! Set this OctahedronPolygon as the subtraction of itself with the given OctahedronPolygon.
 	void inPlaceSubtraction(const OctahedronPolygon& mpoly);
 
 	bool intersects(const OctahedronPolygon& mpoly) const;
@@ -95,10 +98,7 @@ public:
 	bool isEmpty() const;
 
 	static const OctahedronPolygon& getAllSkyOctahedronPolygon();
-	static const OctahedronPolygon& getEmptyOctahedronPolygon() 
-	{
-		static OctahedronPolygon poly; return poly;
-	}
+	static const OctahedronPolygon& getEmptyOctahedronPolygon() {static OctahedronPolygon poly; return poly;}
 
 	static double sphericalTriangleArea(const Vec3d& v0, const Vec3d& v1, const Vec3d& v2)
 	{
@@ -110,18 +110,6 @@ public:
 
 	QString toJson() const;
 
-	//! Get vertices forming triangles filling out the polygon.
-	const QVector<Vec3d>& fillVertices() const
-	{
-		return fillCachedVertexArray;
-	}
-
-	//! Get vertices forming lines outlining the polygon.
-	const QVector<Vec3d>& outlineVertices() const
-	{
-		return outlineCachedVertexArray;
-	}
-
 private:
 	// For unit tests
 	friend class TestStelSphericalGeometry;
@@ -147,7 +135,7 @@ private:
 
 	bool sideContains2D(const Vec3d& p, int sideNb) const;
 
-	//! Tesselate the contours per side, producing a list of triangles subcontours according to the given rule.
+	//! Tesselate the contours per side, producing (in @var sides) a list of triangles subcontours according to the given rule.
 	void tesselate(TessWindingRule rule);
 
 	QVector<SubContour> tesselateOneSideLineLoop(struct GLUEStesselator* tess, int sidenb) const;
@@ -156,12 +144,8 @@ private:
 
 	//! Update the content of both cached vertex arrays.
 	void updateVertexArray();
-
-	//! Vertex array storing triangles of the polygon (each 3 vertices being one triangle).
-	QVector<Vec3d> fillCachedVertexArray;
-	//! Vertex array storing lines of the polygon outline (each 2 vertices being one line).
-	QVector<Vec3d> outlineCachedVertexArray;
-
+	StelVertexArray fillCachedVertexArray;
+	StelVertexArray outlineCachedVertexArray;
 	void computeBoundingCap();
 	Vec3d capN;
 	double capD;
