@@ -45,33 +45,52 @@
 class Extinction
 {
 public:
+	//! Define the extinction strategy for rendering underground objects (usefull when ground is not rendered)
+	enum UndergroundExtinctionMode {
+		UndergroundExtinctionZero = 0,	//!< Zero extinction: stars visible in full brightness
+		UndergroundExtinctionMax = 1,   //!< Maximum extinction: coef 42, i.e practically invisible
+		UndergroundExtinctionMirror = 2 //!< Mirror the extinction for the same altutide above the ground.
+	};
+	
 	Extinction();
+	
 	//! Compute extinction effect for arrays of size @param num position vectors and magnitudes.
-	//! @param altAzPos are the NORMALIZED (!!) (apparent) star position vectors, and their z components sin(apparent_altitude).
-	//! @param mag the magnitudes
-	//! This call must therefore be done after application of Refraction, and only if atmospheric effects are on.
+	//! @param altAzPos are the NORMALIZED (!!) (geometrical) star position vectors, and their z components sin(apparent_altitude).
+	//! This call must therefore be done before application of Refraction if atmospheric effects are on.
 	//! Note that forward/backward are no absolute reverse operations!
-	void forward(const Vec3d *altAzPos, float *mag, const int num=1) const;
-	void forward(const Vec3f *altAzPos, float *mag, const int num=1) const;
-	void forward(const double *sinAlt,  float *mag, const int num) const;
-	void forward(const float  *sinAlt,  float *mag, const int num) const;
-	void forward(const double *sinAlt,  float *mag) const;
-	void forward(const float  *sinAlt,  float *mag) const;
+	void forward(const Vec3d& altAzPos, float* mag) const
+	{
+		Q_ASSERT(std::fabs(altAzPos.length()-1.f)<0.001f);
+		*mag += airmass(altAzPos[2], false) * ext_coeff;
+	}
+	
+	void forward(const Vec3f& altAzPos, float* mag) const
+	{
+		Q_ASSERT(std::fabs(altAzPos.length()-1.f)<0.001f);
+		*mag += airmass(altAzPos[2], false) * ext_coeff;
+	}
 
 	//! Compute inverse extinction effect for arrays of size @param num position vectors and magnitudes.
-	//! @param altAzPos are the NORMALIZED (!!) (apparent) star position vectors, and their z components sin(apparent_altitude).
-	//! @param mag the magnitudes
+	//! @param altAzPos are the NORMALIZED (!!) (geometrical) star position vectors, and their z components sin(apparent_altitude).
 	//! Note that forward/backward are no absolute reverse operations!
-	void backward(const Vec3d *altAzPos, float *mag, const int num=1) const;
-	void backward(const Vec3f *altAzPos, float *mag, const int num=1) const;
-	void backward(const double *sinAlt,  float *mag, const int num=1) const;
-	void backward(const float  *sinAlt,  float *mag, const int num=1) const;
+	void backward(const Vec3d& altAzPos, float* mag) const
+	{
+		*mag -= airmass(altAzPos[2], false) * ext_coeff;
+	}
+	
+	void backward(const Vec3f& altAzPos, float* mag) const
+	{
+		*mag -= airmass(altAzPos[2], false) * ext_coeff;
+	}
 
 	//! Set visual extinction coefficient (mag/airmass), influences extinction computation.
 	//! @param k= 0.1 for highest mountains, 0.2 for very good lowland locations, 0.35 for typical lowland, 0.5 in humid climates.
 	void setExtinctionCoefficient(float k) { ext_coeff=k; }
 	float getExtinctionCoefficient() const {return ext_coeff;}
 
+	void setUndergroundExtinctionMode(UndergroundExtinctionMode mode) {undergroundExtinctionMode=mode;}
+	UndergroundExtinctionMode getUndergroundExtinctionMode() const {return undergroundExtinctionMode;}
+	
 private:
 	//! airmass computation for @param cosZ = cosine of zenith angle z (=sin(altitude)!).
 	//! The default (@param apparent_z = true) is computing airmass from observed altitude, following Rozenberg (1966) [X(90)~40].
@@ -80,13 +99,13 @@ private:
 	//! A problem ist that refraction depends on air pressure and temperature, but Young's formula assumes T=15C, p=1013.25mbar.
 	//! So, it seems better to compute refraction first, and then use the Rozenberg formula here.
 	//! Rozenberg is infinite at Z=92.17 deg, Young at Z=93.6 deg, so this function RETURNS SUBHORIZONTAL_AIRMASS BELOW -2 DEGREES!
-	float airmass(const float cosZ, const bool apparent_z=true) const;
+	float airmass(float cosZ, const bool apparent_z=true) const;
 
 	//! k, magnitudes/airmass, in [0.00, ... 1.00], (default 0.20).
 	float ext_coeff;
-	//! should be either 0.0 (stars visible in full brightness below horizon) or 40.0 (or 42? ;-) practically invisible)
-	//! Maybe make this a user-configurable option?
-	static float SUBHORIZONTAL_AIRMASS;
+
+	//! Define what we are going to do for underground stars when ground is not rendered
+	UndergroundExtinctionMode undergroundExtinctionMode;
 };
 
 //! @class Refraction
@@ -107,124 +126,31 @@ public:
 	//! Apply refraction.
 	//! @param altAzPos is the geometrical star position vector, to be transformed into apparent position.
 	//! Note that forward/backward are no absolute reverse operations!
-	virtual void forward(Vec3d& altAzPos) const;
+	void forward(Vec3d& altAzPos) const;
 
 	//! Remove refraction from position ("reduce").
 	//! @param altAzPos is the apparent star position vector, to be transformed into geometrical position.
 	//! Note that forward/backward are no absolute reverse operations!
-	virtual void backward(Vec3d& altAzPos) const;
+	void backward(Vec3d& altAzPos) const;
 
 	//! Apply refraction.
 	//! @param altAzPos is the geometrical star position vector, to be transformed into apparent position.
 	//! Note that forward/backward are no absolute reverse operations!
-	virtual void forward(Vec3f& altAzPos) const;
+	void forward(Vec3f& altAzPos) const;
 
 	//! Remove refraction from position ("reduce").
 	//! @param altAzPos is the apparent star position vector, to be transformed into geometrical position.
 	//! Note that forward/backward are no absolute reverse operations!
-	virtual void backward(Vec3f& altAzPos) const;
+	void backward(Vec3f& altAzPos) const;
 
-	virtual void combine(const Mat4d& m)
+	void combine(const Mat4d& m)
 	{
 		setPreTransfoMat(preTransfoMat*m);
 	}
 
-	virtual Mat4d getApproximateLinearTransfo() const {return postTransfoMat*preTransfoMat;}
+	Mat4d getApproximateLinearTransfo() const {return postTransfoMat*preTransfoMat;}
 
-	virtual StelProjector::ModelViewTranformP clone() const {Refraction* refr = new Refraction(); *refr=*this; return StelProjector::ModelViewTranformP(refr);}
-
-	virtual bool setupGLSLTransform(StelGLSLShader* shader)
-	{
-		Q_UNUSED(shader);
-		return false;
-
-		// GL-REFACTOR:
-		//
-		// I reimplemented the forward() member function in GLSL, but the result is
-		// not usable at the moment.
-		//
-		// On Intel drivers, the projection gets completely messed up.
-		// On AMD, most of the time, the coordinates are projected in slightly 
-		// different locations (e.g. a planet is slightly above/below where it's
-		// supposed to be), and there is very nasty jitter on the individual vertex 
-		// positions.
-		// NVidia behaves the same, _and_ the viewport borders are messed up.
-		//
-		//
-		// The most likely cause of the problem is the imprecision of GLSL 
-		// sin, asin and tan (which AFAIK are implemented through low-resolution 
-		// lookup tables in hardware).
-		//
-		// However, it is also possible that I incorrectly translated forward() to 
-		// GLSL.
-		//
-		//
-		// Different possible ways to implement refraction in GLSL would be 
-		// to use custom, higher-resolution lookup tables (textures), or to use 
-		// a different, maybe simpler (less trig) algorithm for refraction.
-
-		// if(!shader->hasVertexShader("RefractionTransform"))
-		// {
-		// 	static const QString source(
-		// 		"uniform mat4 preTransfoMat;\n"
-		// 		"uniform mat4 postTransfoMat;\n"
-		// 		"uniform float press_temp_corr_Saemundson;\n"
-		// 		"// These values must match the C++ code.\n"
-		// 		"const float MIN_GEO_ALTITUDE_DEG = -3.54;\n"
-		// 		"const float TRANSITION_WIDTH_GEO_DEG = 1.46;\n"
-		// 		"\n"
-		// 		"vec4 modelViewForward(in vec4 altAzPos)\n"
-		// 		"{\n"
-		// 		"    vec4 localAltAzPos = preTransfoMat * altAzPos;\n"
-		// 		"    float len = length(localAltAzPos.xyz);\n"
-		// 		"    float geom_alt_deg = degrees(asin(localAltAzPos.z / len));\n"
-		// 		"    if(geom_alt_deg > MIN_GEO_ALTITUDE_DEG)\n"
-		// 		"    {\n"
-		// 		"        // refraction from Saemundsson, S&T1986 p70 / in Meeus, Astr.Alg.\n"
-		// 		"        float r = press_temp_corr_Saemundson / \n"
-		// 		"                  tan(radians(geom_alt_deg + 10.3 / (geom_alt_deg + 5.11))) + 0.0019279;\n"
-		// 		"        geom_alt_deg += r;\n"
-		// 		"        geom_alt_deg = min(geom_alt_deg, 90.0); // SAFETY\n" 
-		// 		"        localAltAzPos.z = sin(radians(geom_alt_deg)) * len;\n"
-		// 		"    }\n"
-		// 		"    else if(geom_alt_deg > (MIN_GEO_ALTITUDE_DEG - TRANSITION_WIDTH_GEO_DEG))\n"
-		// 		"    {\n"
-		// 		"        // Avoids the jump below -5 by interpolating linearly between\n"
-		// 		"        // MIN_GEO_ALTITUDE_DEG and bottom of transition zone\n"
-		// 		"        float r_m5 = press_temp_corr_Saemundson / \n"
-		// 		"                     tan(radians(MIN_GEO_ALTITUDE_DEG + 10.3 / (MIN_GEO_ALTITUDE_DEG + 5.11)))\n"
-		// 		"                     + 0.0019279;\n"
-		// 		"        geom_alt_deg += r_m5 * \n"
-		// 		"                        (geom_alt_deg - (MIN_GEO_ALTITUDE_DEG - TRANSITION_WIDTH_GEO_DEG)) /\n"
-		// 		"                        TRANSITION_WIDTH_GEO_DEG;\n"
-		// 		"        localAltAzPos.z = sin(radians(geom_alt_deg)) * len;\n"
-		// 		"    }\n"
-		// 		"    return postTransfoMat * localAltAzPos;\n"
-		// 		"}\n");
-
-		// 	if(!shader->addVertexShader("RefractionTransform", source))
-		// 	{
-		// 		return false;
-		// 	}
-		// 	qDebug() << "Build log after adding a refraction shader: " << shader->log();
-		// }
-		// shader->enableVertexShader("RefractionTransform");
-		// return true;
-	}
-
-	virtual void setGLSLUniforms(StelGLSLShader* shader)
-	{
-		Q_UNUSED(shader);
-		// shader->setUniformValue("preTransfoMat", preTransfoMatf);
-		// shader->setUniformValue("postTransfoMat", postTransfoMatf);
-		// shader->setUniformValue("press_temp_corr_Saemundson", press_temp_corr_Saemundson);
-	}
-
-	virtual void disableGLSLTransform(StelGLSLShader* shader)
-	{
-		Q_UNUSED(shader);
-		// shader->disableVertexShader("RefractionTransform");
-	}
+	StelProjector::ModelViewTranformP clone() const {Refraction* refr = new Refraction(); *refr=*this; return StelProjector::ModelViewTranformP(refr);}
 
 	//! Set surface air pressure (mbars), influences refraction computation.
 	void setPressure(float p_mbar);
@@ -242,6 +168,9 @@ private:
 	//! Update precomputed variables.
 	void updatePrecomputed();
 
+	void innerRefractionForward(Vec3d& altAzPos) const;
+	void innerRefractionBackward(Vec3d& altAzPos) const;
+	
 	//! These 3 Atmosphere parameters can be controlled by GUI.
 	//! Pressure[mbar] (1013)
 	float pressure;
@@ -252,24 +181,6 @@ private:
 	//! Numerator of refraction formula, to be cached for speed.
 	float press_temp_corr_Bennett;
 
-	//! These constants are usable for experiments with the limits of refraction effects.
-	static const double MIN_GEO_ALTITUDE_DEG;
-	static const double MIN_GEO_ALTITUDE_RAD;
-	static const double MIN_GEO_ALTITUDE_SIN;
-	static const double MIN_APP_ALTITUDE_DEG;
-	static const double MIN_APP_ALTITUDE_RAD;
-	static const double MIN_APP_ALTITUDE_SIN;
-	static const float MIN_GEO_ALTITUDE_DEG_F;
-	static const float MIN_GEO_ALTITUDE_RAD_F;
-	static const float MIN_GEO_ALTITUDE_SIN_F;
-	static const float MIN_APP_ALTITUDE_DEG_F;
-	static const float MIN_APP_ALTITUDE_RAD_F;
-	static const float MIN_APP_ALTITUDE_SIN_F;
-	static const double TRANSITION_WIDTH_GEO_DEG;
-	static const double TRANSITION_WIDTH_GEO_DEG_F;
-	static const double TRANSITION_WIDTH_APP_DEG;
-	static const double TRANSITION_WIDTH_APP_DEG_F;
-
 	//! Used to pretransform coordinates into AltAz frame.
 	Mat4d preTransfoMat;
 	Mat4d invertPreTransfoMat;
