@@ -31,6 +31,8 @@ class StelObjectMgr;
 class StelLocaleMgr;
 class StelModuleMgr;
 class StelSkyCultureMgr;
+class StelViewportEffect;
+class QOpenGLFramebufferObject;
 class QSettings;
 class QNetworkAccessManager;
 class QNetworkReply;
@@ -163,6 +165,10 @@ public:
 	//! computer screen with 96 pixel per inch (reference for tuning sizes).
 	float getGlobalScalingRatio() const {return globalScalingRatio;}
 	void setGlobalScalingRatio(float r) {globalScalingRatio=r;}
+
+	//! Get the size of font
+	int getBaseFontSize() const { return baseFontSize; }
+	void setBaseFontSize(int s) { baseFontSize=s; }
 	
 	//! Get the GUI instance implementing the abstract GUI interface.
 	StelGuiBase* getGui() const {return stelGui;}
@@ -185,6 +191,12 @@ public:
 	//! The StelApp instance remains the owner of the controller.
 	StelProgressController* addProgressBar();
 	void removeProgressBar(StelProgressController* p);
+
+	//! Define the type of viewport effect to use
+	//! @param effectName must be one of 'none', 'framebufferOnly', 'sphericMirrorDistorter'
+	void setViewportEffect(const QString& effectName);
+	//! Get the type of viewport effect currently used
+	QString getViewportEffect() const;
 	
 	///////////////////////////////////////////////////////////////////////////
 	// Scriptable methods
@@ -228,7 +240,7 @@ private:
 	//! Handle mouse wheel.
 	void handleWheel(class QWheelEvent* event);
 	//! Handle mouse move.
-	void handleMove(int x, int y, Qt::MouseButtons b);
+	void handleMove(float x, float y, Qt::MouseButtons b);
 	//! Handle key press and release.
 	void handleKeys(class QKeyEvent* event);
 	//! Handle pinch on multi touch devices.
@@ -236,6 +248,9 @@ private:
 
 	void initScriptMgr(QSettings* conf);
 
+	void prepareRenderBuffer();
+	void applyRenderBuffer();
+
 	// The StelApp singleton
 	static StelApp* singleton;
 
@@ -332,6 +347,13 @@ private:
 	qint64 totalUsedCacheSize;
 
 	QList<StelProgressController*> progressControllers;
+
+	int baseFontSize;
+
+	// Framebuffer object used for viewport effects.
+	QOpenGLFramebufferObject* renderBuffer;
+
+	StelViewportEffect* viewportEffect;
 };
 
 #endif // _STELAPP_HPP_
