@@ -21,11 +21,15 @@
 #include <QBuffer>
 #include <QDateTime>
 #include <stdexcept>
+#include <stdio.h>
 
 class StelJsonParserInstance
 {
 public:
-	StelJsonParserInstance(QIODevice* ain) : input(ain), hasNextChar(false)
+	StelJsonParserInstance(QIODevice* ain)
+		: input(ain)
+		, nextChar()
+		, hasNextChar(false)
 	{
 		cur = buffer;
 		last = cur;
