@@ -29,7 +29,12 @@
 class StelMovementMgr : public StelModule
 {
 	Q_OBJECT
-
+	Q_PROPERTY(bool equatorialMount
+			   READ getEquatorialMount
+			   WRITE setEquatorialMount)
+	Q_PROPERTY(bool tracking
+			   READ getFlagTracking
+			   WRITE setFlagTracking)
 public:
 
 	//! Possible mount modes defining the reference frame in which head movements occur.
@@ -53,7 +58,7 @@ public:
 	//! Update time-dependent things (does nothing).
 	virtual void update(double) {;}
 	//! Implement required draw function.  Does nothing.
-	virtual void draw(StelCore*, class StelRenderer*) {;}
+	virtual void draw(StelCore*) {;}
 	//! Handle keyboard events.
 	virtual void handleKeys(QKeyEvent* event);
 	//! Handle mouse movement events.
@@ -62,6 +67,8 @@ public:
 	virtual void handleMouseWheel(class QWheelEvent* event);
 	//! Handle mouse click events.
 	virtual void handleMouseClicks(class QMouseEvent* event);
+	//! Handle pinch gesture.
+	virtual bool handlePinch(qreal scale, bool started);
 
 	///////////////////////////////////////////////////////////////////////////
 	// Methods specific to StelMovementMgr
@@ -194,6 +201,7 @@ public slots:
 	void setMountMode(MountMode m);
 	//! Get current mount type defining the reference frame in which head movements occur.
 	MountMode getMountMode(void) const {return mountMode;}
+	bool getEquatorialMount(void) const {return mountMode == MountEquinoxEquatorial;}
 
 	void setDragTimeMode(bool b) {dragTimeMode=b;}
 	bool getDragTimeMode() const {return dragTimeMode;}
@@ -201,6 +209,11 @@ public slots:
 private slots:
 	//! Called when the selected object changes.
 	void selectedObjectChange(StelModule::StelModuleSelectAction action);
+
+	//! Return the initial value of intensity of art of constellations.
+	double getInitConstellationIntensity() const {return initConstellationIntensity;}
+	//! Set the initial value of intensity of art of constellations.
+	void setInitConstellationIntensity(double v) {initConstellationIntensity=v;}
 	
 private:
 	Vec3d j2000ToMountFrame(const Vec3d& v) const;
@@ -210,6 +223,7 @@ private:
 	double initFov;    // The FOV at startup
 	double minFov;     // Minimum FOV in degree
 	double maxFov;     // Maximum FOV in degree
+	double initConstellationIntensity;   // The initial constellation art intensity (level at startup)
 
 	void setFov(double f)
 	{
@@ -218,8 +232,11 @@ private:
 			currentFov = maxFov;
 		if (f<minFov)
 			currentFov = minFov;
+
+		changeConstellationArtIntensity();
 	}
 	void changeFov(double deltaFov);
+	void changeConstellationArtIntensity();
 
 	void updateVisionVector(double deltaTime);
 	void updateAutoZoom(double deltaTime); // Update autoZoom if activated
