@@ -20,18 +20,24 @@
 #ifndef _STELSKYDRAWER_HPP_
 #define _STELSKYDRAWER_HPP_
 
+#include "RefractionExtinction.hpp"
+#include "StelTextureTypes.hpp"
 #include "StelProjectorType.hpp"
 #include "VecMath.hpp"
-#include "RefractionExtinction.hpp"
-
-#include "renderer/StelIndexBuffer.hpp"
-#include "renderer/StelVertexBuffer.hpp"
 
 #include <QObject>
 
-
 class StelToneReproducer;
 class StelCore;
+class StelPainter;
+
+//! Contains the 2 parameters necessary to draw a star on screen.
+//! the radius and luminance of the star halo texture.
+struct RCMag
+{
+	float radius;
+	float luminance;
+};
 
 //! @class StelSkyDrawer
 //! Provide a set of methods used to draw sky objects taking into account
@@ -40,8 +46,9 @@ class StelSkyDrawer : public QObject
 {
 	Q_OBJECT
 public:
+
 	//! Constructor
-	StelSkyDrawer(StelCore* core, class StelRenderer* renderer);
+	StelSkyDrawer(StelCore* core);
 	//! Destructor
 	~StelSkyDrawer();
 
@@ -52,77 +59,38 @@ public:
 	//! @param deltaTime the time increment in second since last call.
 	void update(double deltaTime);
 
-	//! Prepare to draw point sources (must be called before drawing).
-	void preDrawPointSource();
+	//! Set the proper openGL state before making calls to drawPointSource
+	//! @param p a pointer to a valid instance of a Painter. The instance must be valid until postDrawPointSource() is called
+	void preDrawPointSource(StelPainter* p);
 
-	//! Finalize the drawing of point sources.
-	void postDrawPointSource(StelProjectorP projector);
-
-
-	//! Determine if a point source is visible (should be drawn).
-	//!
-	//! This function is separate from drawPointSource for optimization.
-	//!
-	//! Also projects the point source to window coordinates.
-	//!
-	//! @param projector            Projector to project the point source.
-	//! @param v                    the 3d position of the source in J2000 reference frame
-	//! @param rcMag                the radius and luminance of the source as computed by computeRCMag()
-	//! @param checkInScreen        Whether source in screen should be checked to avoid unnecessary drawing.
-	//! @param outWindowCoordinates Window coordinates out the point source are written here.
-	//!
-	//! @return true if the point source is visible, false otherwise.
-	bool pointSourceVisible(StelProjector* projector, const Vec3f& v, const float rcMag[2],
-	                        bool checkInScreen, Vec3f& outWindowCoordinates)
-	{
-		// If radius is negative
-		if (rcMag[0] <= 0.0f){return false;}
-		return checkInScreen ? projector->projectCheck(v, outWindowCoordinates) 
-		                     : projector->project(v, outWindowCoordinates);
-	}
+	//! Finalize the drawing of point sources
+	void postDrawPointSource(StelPainter* sPainter);
 
 	//! Draw a point source halo.
-	//!
-	//! This is used in combination with pointSourceVisible (which 
-	//! avoids unnecessary draws and projects a point source to window coordinates).
-	//!
-	//! Example:
-	//!
-	//! @code
-	//! Vec3f win;
-	//! if(skyDrawer->pointSourceVisible(&(*projector), pos3D, rcMag, checkInScreen, win))
-	//! {
-	//! 	skyDrawer->drawPointSource(win, rcMag, bV);
-	//! }
-	//! @endcode
-	//!
-	//! @param win   Coordinates of the point source in the window 
-	//!              (computed by pointSourceVisible)
+	//! @param sPainter the StelPainter to use for drawing.
+	//! @param v the 3d position of the source in J2000 reference frame
 	//! @param rcMag the radius and luminance of the source as computed by computeRCMag()
-	//! @param bV    the source B-V index
-	void drawPointSource(const Vec3f& win, const float rcMag[2], unsigned int bV)
-	{
-		return drawPointSource(win, rcMag, colorTable[bV]);
-	}
+	//! @param bV the source B-V index
+	//! @param checkInScreen whether source in screen should be checked to avoid unnecessary drawing.
+	//! @return true if the source was actually visible and drawn
+	bool drawPointSource(StelPainter* sPainter, const Vec3f& v, const RCMag &rcMag, unsigned int bV, bool checkInScreen=false)
+		{return drawPointSource(sPainter, v, rcMag, colorTable[bV], checkInScreen);}
 
-	void drawPointSource(const Vec3f& win, const float rcMag[2], const Vec3f& bcolor);
-
-	//! Draw's the sun's corona during a solar eclipse on earth.
-	void drawSunCorona(StelProjectorP projector, const Vec3d& v, float radius, float alpha);
+	bool drawPointSource(StelPainter* sPainter, const Vec3f& v, const RCMag &rcMag, const Vec3f& bcolor, bool checkInScreen=false);
 
 	//! Terminate drawing of a 3D model, draw the halo
-	//! @param projector Projector to use for this drawing operation
+	//! @param p the StelPainter instance to use for this drawing operation
 	//! @param v the 3d position of the source in J2000 reference frame
 	//! @param illuminatedArea the illuminated area in arcmin^2
 	//! @param mag the source integrated magnitude
 	//! @param color the object halo RGB color
-	void postDrawSky3dModel(StelProjectorP projector, const Vec3d& v, float illuminatedArea, float mag, const Vec3f& color = Vec3f(1.f,1.f,1.f));
+	void postDrawSky3dModel(StelPainter* p, const Vec3f& v, float illuminatedArea, float mag, const Vec3f& color = Vec3f(1.f,1.f,1.f));
 
 	//! Compute RMag and CMag from magnitude.
 	//! @param mag the object integrated V magnitude
 	//! @param rcMag array of 2 floats containing the radius and luminance
 	//! @return false if the object is too faint to be displayed
-	bool computeRCMag(float mag, float rcMag[2]) const;
+	bool computeRCMag(float mag, RCMag*) const;
 
 	//! Report that an object of luminance lum with an on-screen area of area pixels is currently displayed
 	//! This information is used to determine the world adaptation luminance
@@ -176,17 +144,12 @@ public slots:
 	//! Get flag for source twinkling.
 	bool getFlagTwinkle() const {return flagStarTwinkle;}
 
-	//! Set flag for displaying point sources as points (faster on some hardware but not so nice).
-	void setDrawStarsAsPoints(bool b) {drawStarsAsPoints=b;}
-	//! Get flag for displaying point sources as points (faster on some hardware but not so nice).
-	bool getDrawStarsAsPoints() const {return drawStarsAsPoints;}
-
-	//! Set the parameters so that the stars disapear at about the limit given by the bortle scale
+	//! Set the parameters so that the stars disappear at about the limit given by the bortle scale
 	//! The limit is valid only at a given zoom level (around 60 deg)
 	//! See http://en.wikipedia.org/wiki/Bortle_Dark-Sky_Scale
-	void setBortleScale(int index);
+	void setBortleScaleIndex(int index);
 	//! Get the current Bortle scale index
-	int getBortleScale() const {return bortleScaleIndex;}
+	int getBortleScaleIndex() const {return bortleScaleIndex;}
 
 	//! Get the magnitude of the currently faintest visible point source
 	//! It depends on the zoom level, on the eye adapation and on the point source rendering parameters
@@ -248,9 +211,9 @@ public slots:
 	//! Get atmospheric (ground) pressure in mbar (for refraction).
 	double getAtmospherePressure() const {return refraction.getPressure();}
 
-	//! Get the current valid extinction computation class.
+	//! Get the current valid extinction computation object.
 	const Extinction& getExtinction() const {return extinction;}
-	//! Get the current valid fefraction computation class.
+	//! Get the current valid refraction computation object.
 	const Refraction& getRefraction() const {return refraction;}
 
 	//! Get the radius of the big halo texture used when a 3d model is very bright.
@@ -309,16 +272,12 @@ private:
 	float findWorldLumForMag(float mag, float targetRadius);
 
 	StelCore* core;
-
-	//! Used to draw the sky.
-	class StelRenderer* renderer;
 	StelToneReproducer* eye;
 
 	Extinction extinction;
 	Refraction refraction;
 
 	float maxAdaptFov, minAdaptFov, lnfovFactor;
-	bool drawStarsAsPoints;
 	bool flagStarTwinkle;
 	float twinkleAmount;
 
@@ -357,7 +316,7 @@ private:
 	float customNebulaMagLimit;
 
 	//! Little halo texture
-	class StelTextureNew* texHalo;
+	StelTextureSP texHalo;
 
 	//! Load B-V conversion parameters from config file
 	void initColorTableFromConfigFile(class QSettings* conf);
@@ -371,45 +330,34 @@ private:
 	//! The scaling applied to input luminance before they are converted by the StelToneReproducer
 	float inScale;
 
-	//! 2D vertex with position and color.
-	struct ColoredVertex
-	{
-		Vec2f position;
-		Vec3f color;
-		ColoredVertex(Vec2f position, Vec3f color):position(position), color(color){}
-
-		VERTEX_ATTRIBUTES(Vec2f Position, Vec3f Color);
+	// Variables used for GL optimization when displaying point sources
+	//! Vertex format for a point source.
+	//! Texture pos is stored in another separately.
+	struct StarVertex {
+		Vec2f pos;
+		unsigned char color[4];
 	};
+	
+	//! Buffer for storing the vertex array data
+	StarVertex* vertexArray;
 
-	//! 2D vertex with position, color and texture coordinate.
-	struct ColoredTexturedVertex
-	{
-		Vec2f position;
-		Vec3f color;
-		Vec2f texCoord;
-		ColoredTexturedVertex(Vec2f position, Vec3f color, Vec2f texCoord)
-			:position(position), color(color), texCoord(texCoord){}
-
-		VERTEX_ATTRIBUTES(Vec2f Position, Vec3f Color, Vec2f TexCoord);
+	//! Buffer for storing the texture coordinate array data.
+	unsigned char* textureCoordArray;
+	
+	class QOpenGLShaderProgram* starShaderProgram;
+	struct StarShaderVars {
+		int projectionMatrix;
+		int texCoord;
+		int pos;
+		int color;
+		int texture;
 	};
-
-	//! When stars are drawn as points, these are stored in this buffer.
-	StelVertexBuffer<ColoredVertex>* starPointBuffer;
-
-	//! Star sprite triangles.
-	StelVertexBuffer<ColoredTexturedVertex>* starSpriteBuffer;
-
-	//! Big halo triangles.
-	StelVertexBuffer<ColoredTexturedVertex>* bigHaloBuffer;
-
-	//! Sun halo triangles.
-	StelVertexBuffer<ColoredTexturedVertex>* sunHaloBuffer;
-
-	//! Sun corona triangles.
-	StelVertexBuffer<ColoredTexturedVertex>* coronaBuffer;
-
-	//! Are we drawing point sources at the moment?
-	bool drawing;
+	StarShaderVars starShaderVars;
+	
+	//! Current number of sources stored in the buffers (still to display)
+	unsigned int nbPointSources;
+	//! Maximum number of sources which can be stored in the buffers
+	unsigned int maxPointSources;
 
 	//! The maximum transformed luminance to apply at the next update
 	float maxLum;
@@ -417,24 +365,12 @@ private:
 	float oldLum;
 
 	//! Big halo texture
-	class StelTextureNew* texBigHalo;
-	class StelTextureNew* texSunHalo;
-	class StelTextureNew* texCorona;
+	StelTextureSP texBigHalo;
+	StelTextureSP texSunHalo;
 
 	bool flagLuminanceAdaptation;
 
 	float big3dModelHaloRadius;
-
-
-	//! Are the statistics IDs initialized?
-	bool statisticsInitialized;
-
-	//! ID used to modify the big halo draw statistic.
-	int bigHaloStatID;
-	//! ID used to modify the sun halo draw statistic.
-	int sunHaloStatID;
-	//! ID used to modify the star draw statistic.
-	int starStatID;
 };
 
 #endif // _STELSKYDRAWER_HPP_
