@@ -19,21 +19,21 @@
 #ifndef _STELSKYLAYERMGR_HPP_
 #define _STELSKYLAYERMGR_HPP_
 
+#include "StelModule.hpp"
+#include "StelSkyLayer.hpp"
+
 #include <QString>
 #include <QStringList>
 #include <QMap>
 
-#include "StelModule.hpp"
-#include "StelSkyLayer.hpp"
-
 class StelCore;
 class StelSkyImageTile;
-class QProgressBar;
 
 //! Manage the sky background images, including DSS and deep sky objects images
 class StelSkyLayerMgr : public StelModule
 {
 	Q_OBJECT
+	Q_PROPERTY(bool visible READ getFlagShow WRITE setFlagShow)
 
 public:
 	StelSkyLayerMgr();
@@ -45,7 +45,7 @@ public:
 	virtual void init();
 
 	//! Draws sky background
-	virtual void draw(StelCore* core, class StelRenderer* renderer);
+	virtual void draw(StelCore* core);
 
 	//! Update state which is time dependent.
 	virtual void update(double) {;}
@@ -70,14 +70,14 @@ public:
 
 	StelSkyLayerP getSkyLayer(const QString& key) const;
 
+	//! Get whether Sky Background should be displayed
+	bool getFlagShow() const {return flagShow;}
+
 public slots:
 	///////////////////////////////////////////////////////////////////////////
 	// Properties setters and getters
 	//! Set whether Sky Background should be displayed
 	void setFlagShow(bool b) {flagShow = b;}
-	//! Get whether Sky Background should be displayed
-	bool getFlagShow() const {return flagShow;}
-
 	//! Load an image from a file. This should not be called directly from
 	//! scripts because it is not thread safe.  Instead use the simiarly
 	//! named function in the core scripting object.
@@ -180,7 +180,7 @@ private:
 		SkyLayerElem(StelSkyLayerP t, bool show=true);
 		~SkyLayerElem();
 		StelSkyLayerP layer;
-		QProgressBar* progressBar;
+		class StelProgressController* progressBar;
 		bool show;
 	};
 
