@@ -21,61 +21,24 @@
 #define _STELTEXTURE_HPP_
 
 #include "StelTextureTypes.hpp"
+#include "StelOpenGL.hpp"
 
 #include <QObject>
 #include <QImage>
-#include <QtOpenGL>
-//FIXME: After fully migrate to Qt 4.8 this condition need drop
-#if QT_VERSION>=0x040800
-#include <QGLFunctions>
-#endif
 
 class QFile;
 class StelTextureMgr;
 class QNetworkReply;
+template <class T> class QFuture;
 
 #ifndef GL_CLAMP_TO_EDGE
 #define GL_CLAMP_TO_EDGE 0x812F
 #endif
 
-// This class is just used internally to load the texture data.
-class ImageLoader : QObject
-{
-	Q_OBJECT
-
-private:
-	friend class StelTextureMgr;
-	friend class StelTexture;
-
-	ImageLoader(const QString& path, int delay);
-	void abort();
-
-signals:
-	void finished(QImage);
-	void error(const QString& errorMsg);
-
-public slots:
-	void start();
-
-private slots:
-	void onNetworkReply();
-	void directLoad();
-
-private:
-	QString path;
-	QNetworkReply* networkReply;
-};
-
 //! @class StelTexture
 //! Base texture class. For creating an instance, use StelTextureMgr::createTexture() and StelTextureMgr::createTextureThread()
 //! @sa StelTextureSP
-class StelTexture
-//FIXME: After fully migrate to Qt 4.8 this condition need drop
-#if QT_VERSION>=0x040800
-		: public QObject, protected QGLFunctions
-#else
-		: public QObject
-#endif
+class StelTexture: public QObject
 {
 	Q_OBJECT
 
@@ -102,7 +65,7 @@ public:
 	//! If the texture is lazyly loaded, this starts the loading and return false immediately.
 	//! @return true if the binding successfully occured, false if the texture is not yet loaded.
 	
-	bool bind();
+	bool bind(int slot=0);
 
 	//! Return whether the texture can be binded, i.e. it is fully loaded
 	bool canBind() const {return id!=0;}
@@ -119,12 +82,7 @@ public:
 	const QString& getFullPath() const {return fullPath;}
 
 	//! Return whether the image is currently being loaded
-	bool isLoading() const {return isLoadingImage && !canBind();}
-
-	//! Load the texture already in the RAM to the openGL memory
-	//! This function uses openGL routines and must be called in the main thread
-	//! @return false if an error occured
-	bool glLoad();
+	bool isLoading() const {return (loader || networkReply) && !canBind();}
 
 signals:
 	//! Emitted when the texture is ready to be bind(), i.e. when downloaded, imageLoading and	glLoading is over
@@ -134,41 +92,56 @@ signals:
 	void loadingProcessFinished(bool error);
 
 private slots:
-	//! Called by the loader when the data has finished loading
-	void onImageLoaded(QImage image);
-	//! Called by the loader in case of an error
-	void onLoadingError(const QString& errorMessage) {reportError(errorMessage);}
+	void onNetworkReply();
 
 private:
 	friend class StelTextureMgr;
-	friend class TextureLoader;
+
+	//! structure returned by the loader threads, containing all the
+	//! data and information to create the OpenGL texture.
+	struct GLData
+	{
+		GLData() : data(NULL), width(0), height(0), format(0), type(0) {}
+		QByteArray data;
+		int width;
+		int height;
+		GLint format;
+		GLint type;
+	};
+	//! Those static methods can be called by QtConcurrent::run
+	static GLData imageToGLData(const QImage &image);
+	static GLData loadFromPath(const QString &path);
+	static GLData loadFromData(const QByteArray& data);
 
 	//! Private constructor
 	StelTexture();
 
+	//! Convert a QImage into opengl compatible format.
+	static QByteArray convertToGLFormat(const QImage& image, GLint* format, GLint* type);
+
 	//! This method should be called if the texture loading failed for any reasons
 	//! @param errorMessage the human friendly error message
 	void reportError(const QString& errorMessage);
 
+	//! Load the texture already in the RAM to the openGL memory
+	//! This function uses openGL routines and must be called in the main thread
+	//! @return false if an error occured
+	bool glLoad(const QImage& image);
+	//! Same as glLoad(QImage), but with an image already in OpenGl format
+	bool glLoad(const GLData& data);
+
 	StelTextureParams loadParams;
 
+	//! Used to handle the connection for remote textures.
+	QNetworkReply *networkReply;
+
 	//! The loader object
-	ImageLoader* loader;
+	QFuture<GLData>* loader;
 
-	//! Define if the texture was already downloaded if it was a remote one
-	bool downloaded;
-	//! Define whether the image is already loading
-	bool isLoadingImage;
 
 	//! The URL where to download the file
 	QString fullPath;
 
-	//! The data that was loaded from http
-	QImage qImage;
-
-	//! Used ony when creating temporary file
-	QString fileExtension;
-
 	//! True when something when wrong in the loading process
 	bool errorOccured;
 
