@@ -19,8 +19,9 @@
 #ifndef _STELTONEREPRODUCER_HPP_
 #define _STELTONEREPRODUCER_HPP_
 
-#include <QDebug>
+#include "config.h"
 
+#include <cmath>
 
 //! Converts tones in function of the eye adaptation to luminance.
 //! The aim is to get on the screen something which is perceptualy accurate,
@@ -53,10 +54,10 @@ class StelToneReproducer
 {
 public:
 	//! Constructor
-    StelToneReproducer();
+	StelToneReproducer();
 	
 	//! Desctructor
-    virtual ~StelToneReproducer();
+	virtual ~StelToneReproducer();
 
 	//! Set the eye adaptation luminance for the display (and precompute what can be)
 	//! Usual luminance range is 1-100 cd/m^2 for a CRT screen
@@ -71,29 +72,42 @@ public:
 	//! Sun Light       : 100000 cd/m^2
 	void setWorldAdaptationLuminance(float worldAdaptationLuminance);
 	//! Get the eye adaptation luminance for the world
-	float getWorldAdaptationLuminance() const {return Lwa;}
+	float getWorldAdaptationLuminance() const
+	{
+		return Lwa;
+	}
 	
 	//! Set the global scale applied to input lumiances, i.e before the adaptation
 	//! It is the parameter to modify to simulate aperture*exposition time
 	//! @param scale the global input scale
 	void setInputScale(float scale=1.f);
 	//! Get the global scale applied to input lumiances, i.e before the adaptation
-	float getInputScale() const {return inputScale;}
+	float getInputScale() const
+	{
+		return inputScale;
+	}
 	
 	//! Set the maximum luminance of the display (CRT, screen etc..)
 	//! This value is used to scale the RGB range
 	//! @param maxdL the maximum lumiance in cd/m^2. Initial default value is 120 cd/m^2
 	void setMaxDisplayLuminance(float maxdL)
-	{oneOverMaxdL = 1.f/maxdL; lnOneOverMaxdL=std::log(oneOverMaxdL); term2TimesOneOverMaxdLpOneOverGamma = std::pow(term2*oneOverMaxdL, oneOverGamma);}
+	{
+		oneOverMaxdL = 1.f/maxdL; lnOneOverMaxdL=std::log(oneOverMaxdL); term2TimesOneOverMaxdLpOneOverGamma = std::pow(term2*oneOverMaxdL, oneOverGamma);
+	}
 
 	//! Get the display gamma
 	//! @return the display gamma. Default value is 2.2222 for a CRT
-	float getDisplayGamma() const {return 1.f/oneOverGamma;}
+	float getDisplayGamma() const
+	{
+		return 1.f/oneOverGamma;
+	}
 	
 	//! Set the display gamma
 	//! @param gamma the gamma. Initial default value is 2.2222
 	void setDisplayGamma(float gamma)
-	{oneOverGamma = 1.f/gamma; term2TimesOneOverMaxdLpOneOverGamma = std::pow(term2*oneOverMaxdL, oneOverGamma);}
+	{
+		oneOverGamma = 1.f/gamma; term2TimesOneOverMaxdLpOneOverGamma = std::pow(term2*oneOverMaxdL, oneOverGamma);
+	}
 
 	//! Return adapted luminance from world to display
 	//! @param worldLuminance the world luminance to convert in cd/m^2
@@ -108,7 +122,7 @@ public:
 	//! @return the converted world luminance in cd/m^2
 	float reverseAdaptLuminance(float displayLuminance) const
 	{
-		return std::pow((float)(displayLuminance/term2),1.f/alphaWaOverAlphaDa)/(inputScale*M_PI*0.0001f);
+		return (float) std::pow((float)(displayLuminance/term2),1.f/alphaWaOverAlphaDa)/(inputScale*M_PI*0.0001f);
 	}
 	
 	//! Return adapted luminance from world to display with 1 corresponding to full display white
@@ -134,23 +148,7 @@ public:
 	float adaptLuminanceScaledLn(float lnWorldLuminance, float pFact=0.5f) const
 	{
 		const float lnPix0p0001 = -8.0656104861f;
-		//Needs better name
-		const float temp        = ((lnInputScale + lnWorldLuminance + lnPix0p0001) * 
-		                            alphaWaOverAlphaDa+lnTerm2 + lnOneOverMaxdL) * pFact;
-
-		// Optimization:
-		// Always using exp here takes 6-9% of runtime in release mode.
-		// This code is used to determine point source radius.
-		//
-		// If this value is < 5 (and < 4, for that matter), the star won't 
-		// even be displayed as it's radius is too low. We also get rid 
-		// of ~90% of exp calls.
-		if(temp < -5.0f)
-		{
-			return 0.0f;
-		}
-
-		return std::exp(temp);
+		return std::exp(((lnInputScale+lnWorldLuminance+lnPix0p0001)*alphaWaOverAlphaDa+lnTerm2+lnOneOverMaxdL)*pFact);
 	}
 	
 	//! Convert from xyY color system to RGB.
