@@ -77,6 +77,18 @@ namespace StelUtils
 	//! @param s second component
 	void radToDms(double rad, bool& sign, unsigned int& d, unsigned int& m, double& s);
 
+	//! Convert an angle in radian to decimal degree.
+	//! @param rad input angle in radian
+	//! @param sign true if positive, false otherwise
+	//! @param deg decimal degree
+	void radToDecDeg(double rad, bool& sign, double& deg);
+
+	//! Convert an angle in radian to a decimal degree string.
+	//! @param angle input angle in radian
+	//! @param useD Define if letter "d" must be used instead of deg sign
+	//! @param useC Define if function should use 0-360 degrees
+	QString radToDecDegStr(const double angle, const bool useD=false, const bool useC=false);
+
 	//! Convert an angle in radian to a hms formatted string.
 	//! If the second, minute part is == 0, it is not output
 	//! @param angle input angle in radian
@@ -99,6 +111,18 @@ namespace StelUtils
 	//! @param decimal output decimal second value
 	QString radToDmsStr(const double angle, const bool decimal=false, const bool useD=false);
 
+	//! Convert an angle in decimal degree to +-dms format.
+	//! @param angle input angle in decimal degree
+	//! @param sign true if positive, false otherwise
+	//! @param d degree component
+	//! @param m minute component
+	//! @param s second component
+	void decDegToDms(double angle, bool& sign, unsigned int& d, unsigned int& m, double& s);
+
+	//! Convert an angle in decimal degrees to a dms formatted string.
+	//! @param angle input angle in decimal degrees
+	QString decDegToDmsStr(const double angle);
+
 	//! Convert a dms formatted string to an angle in radian
 	//! @param s The input string
 	double dmsStrToRad(const QString& s);
