@@ -18,12 +18,14 @@
  */
 
 // Template vector and matrix library.
-// Use column-major matrices, and in vectors, order vertices like this:
-// x, y, z, w (or r, g, b, a), so they can be passed to Renderer.
+// Use OpenGL compatible ordering ie. you can pass a matrix or vector to
+// openGL functions without changes in the ordering
 
 #ifndef _VECMATH_H_
 #define _VECMATH_H_
 
+#include "config.h"
+
 #include <cmath>
 #include <QString>
 
@@ -37,36 +39,36 @@ typedef Vector2<float>	Vec2f;
 typedef Vector2<int>	Vec2i;
 
 //! @typedef Vec3d
-//! A 3d vector of doubles.
+//! A 3d vector of doubles compatible with openGL.
 typedef Vector3<double>	Vec3d;
 
 //! @typedef Vec3f
-//! A 3d vector of floats.
+//! A 3d vector of floats compatible with openGL.
 typedef Vector3<float>	Vec3f;
 
 //! @typedef Vec4d
-//! A 4d vector of doubles.
+//! A 4d vector of doubles compatible with openGL.
 typedef Vector4<double>	Vec4d;
 
 //! @typedef Vec4f
-//! A 4d vector of floats.
+//! A 4d vector of floats compatible with openGL.
 typedef Vector4<float>	Vec4f;
 
 //! @typedef Vec4i
-//! A 4d vector of ints.
+//! A 4d vector of ints compatible with openGL.
 typedef Vector4<int>	Vec4i;
 
 //! @typedef Mat4d
-//! A 4x4 matrix of doubles.
+//! A 4x4 matrix of doubles compatible with openGL.
 typedef Matrix4<double>	Mat4d;
 
 //! @typedef Mat4f
-//! A 4x4 matrix of floats.
+//! A 4x4 matrix of floats compatible with openGL.
 typedef Matrix4<float>	Mat4f;
 
 
 //! @class Vector2
-//! A templatized 2d vector.
+//! A templatized 2d vector compatible with openGL.
 //! Use Vec2d or Vec2f typdef for vectors of double and float respectively.
 template<class T> class Vector2
 {
@@ -111,7 +113,7 @@ public:
 
 
 //! @class Vector3
-//! A templatized 3d vector.
+//! A templatized 3d vector compatible with openGL.
 //! Use Vec3d or Vec3f typdef for vectors of double and float respectively.
 template<class T> class Vector3
 {
@@ -178,7 +180,7 @@ public:
 
 
 //! @class Vector4
-//! A templatized 4d vector.
+//! A templatized 4d vector compatible with openGL.
 //! Use Vec4d or Vec4f typdef for vectors of double and float respectively.
 template<class T> class Vector4
 {
@@ -227,7 +229,7 @@ public:
 };
 
 //! @class Matrix4
-//! A templatized column-major 4x4 matrix.
+//! A templatized column-major 4x4 matrix compatible with openGL.
 //! Use Mat4d or Mat4f typdef for matrices of doubles and floats respectively.
 template<class T> class Matrix4
 {
@@ -995,7 +997,7 @@ template<class T> Matrix4<T> Matrix4<T>::inverse() const
 	const T * m = r;
 	T out[16];
 
-/* NB. Matrices used by StelRenderer are COLUMN major. */
+/* NB. OpenGL Matrices are COLUMN major. */
 #define SWAP_ROWS(a, b) { T *_tmp = a; (a)=(b); (b)=_tmp; }
 #define MAT(m,r,c) (m)[(c)*4+(r)]
 
