@@ -24,33 +24,28 @@
 #include "Skylight.hpp"
 #include "VecMath.hpp"
 
-#include "renderer/StelIndexBuffer.hpp"
-#include "renderer/StelVertexBuffer.hpp"
 #include "Skybright.hpp"
 #include "StelFader.hpp"
-#include "StelProjector.hpp"
+
+#include <QOpenGLBuffer>
 
 class StelProjector;
 class StelToneReproducer;
 class StelCore;
 
-//! Compute and display the daylight sky color.
+//! Compute and display the daylight sky color using openGL.
 //! The sky brightness is computed with the SkyBright class, the color with the SkyLight.
 //! Don't use this class directly but use it through the LandscapeMgr.
 class Atmosphere
 {
 public:
-	Atmosphere(void);
-	virtual ~Atmosphere(void);
-
-	//! Called on every update to recompute colors of the atmosphere.
-	//!
-	//! Must be called at least once after a call to draw(), as vertexGrid 
-	//! is lazily initialized at the first draw call.
+	Atmosphere();
+	virtual ~Atmosphere();
+	
 	void computeColor(double JD, Vec3d _sunPos, Vec3d moonPos, float moonPhase, StelCore* core,
-					  float eclipseFac, float latitude = 45.f, float altitude = 200.f,
-					  float temperature = 15.f, float relativeHumidity = 40.f);
-	void draw(StelCore* core, class StelRenderer* renderer);
+		float latitude = 45.f, float altitude = 200.f,
+		float temperature = 15.f, float relativeHumidity = 40.f);
+	void draw(StelCore* core);
 	void update(double deltaTime) {fader.update((int)(deltaTime*1000));}
 
 	//! Set fade in/out duration in seconds
@@ -65,16 +60,16 @@ public:
 
 	//! Get the actual atmosphere intensity due to eclipses + fader
 	//! @return the display intensity ranging from 0 to 1
-	float getRealDisplayIntensityFactor(void) const {return fader.getInterstate()*eclipseFactor;}
+	float getRealDisplayIntensityFactor() const {return fader.getInterstate()*eclipseFactor;}
 
 	// let's you know how far faded in or out the atm is (0-1)
-	float getFadeIntensity(void) const {return fader.getInterstate();}
+	float getFadeIntensity() const {return fader.getInterstate();}
 
 	//! Get the average luminance of the atmosphere in cd/m2
 	//! If atmosphere is off, the luminance includes the background starlight + light pollution.
 	//! Otherwise it includes the atmosphere + background starlight + eclipse factor + light pollution.
 	//! @return the last computed average luminance of the atmosphere in cd/m2.
-	float getAverageLuminance(void) const {return averageLuminance;}
+	float getAverageLuminance() const {return averageLuminance;}
 
 	//! Set the light pollution luminance in cd/m^2
 	void setLightPollutionLuminance(float f) { lightPollutionLuminance = f; }
@@ -82,19 +77,16 @@ public:
 	float getLightPollutionLuminance() const { return lightPollutionLuminance; }
 
 private:
-	// Vertex with a 2D position and a color.
-	struct Vertex
-	{
-		Vec2f position;
-		Vec4f color;
-		Vertex(const Vec2f position, const Vec4f& color) : position(position), color(color) {}
-		VERTEX_ATTRIBUTES(Vec2f Position, Vec4f Color);
-	};
-
 	Vec4i viewport;
 	Skylight sky;
 	Skybright skyb;
-	int skyResolutionY, skyResolutionX;
+	int skyResolutionY,skyResolutionX;
+
+	Vec2f* posGrid;
+	QOpenGLBuffer posGridBuffer;
+	QOpenGLBuffer indicesBuffer;
+	Vec4f* colorGrid;
+	QOpenGLBuffer colorGridBuffer;
 
 	//! The average luminance of the atmosphere in cd/m2
 	float averageLuminance;
@@ -102,33 +94,20 @@ private:
 	LinearFader fader;
 	float lightPollutionLuminance;
 
-	//! Shader used for xyYToRGB computation. If NULL, shader is not used.
-	class StelGLSLShader* shader;
-
-	//! Rectangular grid of vertices making up the atmosphere.
-	StelVertexBuffer<Vertex>* vertexGrid;
-
-	//! Index buffers representing triangle strips for each row in the grid.
-	QVector<StelIndexBuffer*> rowIndices;
-
-	//! Renderer used to construct row index buffers at viewport changes.
-	//!
-	//! Lazily initialized - NULL until the first draw call.
-	class StelRenderer* renderer;
-
-	//! Lazily loads the shader used for drawing.
-	//!
-	//! Called at the first call to draw().
-	//!
-	//! This should only be called if the Renderer supports GLSL.
-	//!
-	//! @return true on success, false on failure (allowing for a shader-less fallback).
-	bool lazyLoadShader(class StelRenderer* renderer);
-
-	//! Update the vertex grid and index buffers.
-	//!
-	//! Called by computeColor after the viewport changes.
-	void updateGrid(const StelProjectorP projector);
+	//! Vertex shader used for xyYToRGB computation
+	class QOpenGLShaderProgram* atmoShaderProgram;
+	struct {
+		int alphaWaOverAlphaDa;
+		int oneOverGamma;
+		int term2TimesOneOverMaxdLpOneOverGamma;
+		int brightnessScale;
+		int sunPos;
+		int term_x, Ax, Bx, Cx, Dx, Ex;
+		int term_y, Ay, By, Cy, Dy, Ey;
+		int projectionMatrix;
+		int skyVertex;
+		int skyColor;
+	} shaderAttribLocations;
 };
 
 #endif // _ATMOSTPHERE_HPP_
