@@ -52,7 +52,7 @@ Comet::Comet(const QString& englishName,
 		 OsculatingFunctType *osculatingFunc,
 		 bool acloseOrbit,
 		 bool hidden,
-		 const QString& pType,
+		 const QString& pTypeStr,
 		 float dustTailWidthFact, float dustTailLengthFact, float dustTailBrightnessFact)
 	: Planet (englishName,
 		  flagLighting,
@@ -69,7 +69,8 @@ Comet::Comet(const QString& englishName,
 		  hidden,
 		  false, //No atmosphere
 		  true, //halo
-		  pType),
+		  pTypeStr),
+	  tailActive(false),
 	  dustTailWidthFactor(dustTailWidthFact),
 	  dustTailLengthFactor(dustTailLengthFact),
 	  dustTailBrightnessFactor(dustTailBrightnessFact)
@@ -77,6 +78,8 @@ Comet::Comet(const QString& englishName,
 	texMapName = atexMapName;
 	lastOrbitJD =0;
 	deltaJD = StelCore::JD_SECOND;
+	deltaJDtail=15.0*StelCore::JD_MINUTE; // update tail geometry every 15 minutes only
+	lastJDtail=0.0;
 	orbitCached = 0;
 	closeOrbit = acloseOrbit;
 
@@ -86,18 +89,7 @@ Comet::Comet(const QString& englishName,
 
 	gastailVertexArr.clear();
 	dusttailVertexArr.clear();
-	gastailTexCoordArr.clear();
-	//dusttailTexCoordArr.clear();
-	gastailIndices.clear();
-	//dusttailIndices.clear();
 	comaVertexArr.clear();
-	comaTexCoordArr.clear();
-
-	comaTexture = StelApp::getInstance().getTextureManager().createTextureThread(StelFileMgr::getInstallationDir()+"/textures/cometComa.png", StelTexture::StelTextureParams(true, GL_LINEAR, GL_CLAMP_TO_EDGE));
-	//GZ: tail textures. We use a paraboloid tail body, textured like a fisheye sphere, i.e. center=head. The texture should be something like a mottled star to give some structure.
-	gasTailTexture = StelApp::getInstance().getTextureManager().createTextureThread(StelFileMgr::getInstallationDir()+"/textures/cometTail.png", StelTexture::StelTextureParams(true, GL_LINEAR, GL_CLAMP_TO_EDGE));
-	// GZ: I think we need only one texture for the tails.
-	//dusttailTexture = StelApp::getInstance().getTextureManager().createTextureThread(StelFileMgr::getInstallationDir()+"/textures/cometTail.png", StelTexture::StelTextureParams(true, GL_LINEAR, GL_CLAMP_TO_EDGE));
 
 	//Comet specific members
 	absoluteMagnitude = 0;
@@ -151,8 +143,7 @@ QString Comet::getInfoString(const StelCore *core, const InfoStringGroup &flags)
 
 	if (flags&ObjectType)
 	{
-		if (pType.length()>0)
-			oss << q_("Type: <b>%1</b>").arg(q_(pType)) << "<br />";
+		oss << q_("Type: <b>%1</b>").arg(q_(getPlanetTypeString())) << "<br />";
 	}
 
 	if (flags&Magnitude)
@@ -212,17 +203,28 @@ QString Comet::getInfoString(const StelCore *core, const InfoStringGroup &flags)
 				   .arg(distanceKm / 1.0e6, 0, 'f', 3);
 		}
 		oss << "<br>";
-		// GZ: Add speed. I don't know where to place that bit of information.
+	}
+	if (flags&Extra)
+	{
+		// GZ: Add speed. I don't know where else to place that bit of information.
 		// xgettext:no-c-format
 		oss << QString(q_("Speed: %1 km/s"))
 			   .arg(((CometOrbit*)userDataPtr)->getVelocity().length()*AU/86400.0, 0, 'f', 3);
 		oss << "<br>";
 	}
 
-	/*
 	if (flags&Size)
-		oss << q_("Apparent diameter: %1").arg(StelUtils::radToDmsStr(2.*getAngularSize(core)*M_PI/180., true));
-	*/
+	{
+		// GZ: Add estimates for coma diameter and tail length.
+		// xgettext:no-c-format
+		oss << QString(q_("Coma diameter (estimate): %1 km"))
+			   .arg(floor(tailFactors[0]*AU/1000.0f)*1000.0f, 0, 'f', 0);
+		oss << "<br>";
+		// xgettext:no-c-format
+		oss << QString(q_("Gas tail length (estimate): %1 Mio km"))
+			   .arg(tailFactors[1]*AU*1e-6, 0, 'G', 3);
+		oss << "<br>";
+	}
 
 	// If semi-major axis not zero then calculate and display orbital period for comet in days
 	double siderealPeriod = getSiderealPeriod();
@@ -279,52 +281,100 @@ float Comet::getVMagnitude(const StelCore* core) const
 	return apparentMagnitude;
 }
 
+// Compute the position in the parent Planet coordinate system
+// Actually call the provided function to compute the ecliptical position, and buildup the tails!
+void Comet::computePosition(const double date)
+{
+	Planet::computePosition(date);
+	//GZ: I think we can make deltaJD adaptive, depending on distance to sun! For some reason though, this leads to a crash!
+	//deltaJD=StelCore::JD_SECOND * qMax(1.0, qMin(eclipticPos.length(), 20.0));
+
+	if (fabs(lastJDtail-date)>deltaJDtail)
+	{
+		lastJDtail=date;
+
+		// GZ: Moved from draw() :-)
+		// The CometOrbit is in fact available in userDataPtr!
+		CometOrbit* orbit=(CometOrbit*)userDataPtr;
+		Q_ASSERT(orbit);
+		if (!orbit->objectDateValid(date)) return; // out of useful date range. This should allow having hundreds of comet elements.
+
+		if (orbit->getUpdateTails()){
+			// Compute lengths and orientations from orbit object, but only if required.
+			// This part moved from draw() to keep draw() free from too much computation.
+			tailFactors=getComaDiameterAndTailLengthAU();
+
+			// Note that we use a diameter larger than what the formula returns. A scale factor of 1.2 is ad-hoc/empirical (GZ), but may look better.
+			computeComa(1.0f*tailFactors[0]);
+
+			tailActive = (tailFactors[1] > tailFactors[0]); // Inhibit tails drawing if too short. Would be nice to include geometric projection angle, but this is too costly.
+
+			if (tailActive)
+			{
+				float gasTailEndRadius=qMax(tailFactors[0], 0.025f*tailFactors[1]) ; // This avoids too slim gas tails for bright comets like Hale-Bopp.
+				float gasparameter=gasTailEndRadius*gasTailEndRadius/(2.0f*tailFactors[1]); // parabola formula: z=r²/2p, so p=r²/2z
+				// The dust tail is thicker and usually shorter. The factors can be configured in the elements.
+				float dustparameter=gasTailEndRadius*gasTailEndRadius*dustTailWidthFactor*dustTailWidthFactor/(2.0f*dustTailLengthFactor*tailFactors[1]);
+
+				// Find valid parameters to create paraboloid vertex arrays: dustTail, gasTail.
+				computeParabola(gasparameter, gasTailEndRadius, -0.5f*gasparameter, gastailVertexArr,  tailTexCoordArr, tailIndices);
+				// This was for a rotated straight parabola:
+				//computeParabola(dustparameter, 2.0f*tailFactors[0], -0.5f*dustparameter, dusttailVertexArr, dusttailTexCoordArr, dusttailIndices);
+				// Now we make a skewed parabola. Skew factor (xOffset, last arg) is rather ad-hoc/empirical. TBD later: Find physically correct solution.
+				computeParabola(dustparameter, dustTailWidthFactor*gasTailEndRadius, -0.5f*dustparameter, dusttailVertexArr, tailTexCoordArr, tailIndices, 25.0f*orbit->getVelocity().length());
+
+
+				// 2014-08 for 0.13.1 Moved from drawTail() to save lots of computation per frame (There *are* folks downloading all 730 MPC current comet elements...)
+				// Find rotation matrix from 0/0/1 to eclipticPosition: crossproduct for axis (normal vector), dotproduct for angle.
+				Vec3d eclposNrm=eclipticPos; eclposNrm.normalize();
+				gasTailRot=Mat4d::rotation(Vec3d(0.0, 0.0, 1.0)^(eclposNrm), std::acos(Vec3d(0.0, 0.0, 1.0).dot(eclposNrm)) );
+
+				Vec3d velocity=orbit->getVelocity(); // [AU/d]
+				// This was a try to rotate a straight parabola somewhat away from the antisolar direction.
+				//Mat4d dustTailRot=Mat4d::rotation(eclposNrm^(-velocity), 0.15f*std::acos(eclposNrm.dot(-velocity))); // GZ: This scale factor of 0.15 is empirical from photos of Halley and Hale-Bopp.
+				// The curved tail is curved towards positive X. We first rotate around the Z axis into a direction opposite of the motion vector, then again the antisolar rotation applies.
+				// In addition, we let the dust tail already start with a light tilt.
+				dustTailRot=gasTailRot * Mat4d::zrotation(atan2(velocity[1], velocity[0]) + M_PI) * Mat4d::yrotation(5.0f*velocity.length());
+
+				// TODO: If we want to be even faster, rotate vertex arrays here and not in drawTail()!
+				Vec3d* gasVertices=(Vec3d*) (gastailVertexArr.data());
+				Vec3d* dustVertices=(Vec3d*) (dusttailVertexArr.data());
+				for (int i=0; i<COMET_TAIL_SLICES*COMET_TAIL_STACKS+1; ++i)
+				{
+					gasVertices[i].transfo4d(gasTailRot);
+					dustVertices[i].transfo4d(dustTailRot);
+				}
+			}
+
+			orbit->setUpdateTails(false); // don't update until position has been recalculated elsewhere
+		}
+		// Note: we can make deltaJDtail adaptive, depending on distance to sun!
+		//deltaJDtail=5.0*StelCore::JD_MINUTE * qMax(0.01, qMin(eclipticPos.length(), 20.0));
+	}
+}
+
+
 // Draw the Comet and all the related infos : name, circle etc... GZ: Taken from Planet.cpp 2013-11-05 and extended
 void Comet::draw(StelCore* core, float maxMagLabels, const QFont& planetNameFont)
 {
 	if (hidden)
 		return;
 	if (getEnglishName() == core->getCurrentLocation().planetName)
-	{ // GZ moved this up. Maybe even don't do that? E.g., draw tail while riding the comet? Decide later.
+	{ // GZ: Maybe even don't do that? E.g., draw tail while riding the comet? Decide later.
 		return;
 	}
 
+	// GZ: If comet is too faint to be seen, don't bother rendering. (oops, should have been here in 2014-01... ;-)
+	if ((getVMagnitude(core)-2.0f) > core->getSkyDrawer()->getLimitMagnitude())
+	{
+		return;
+	}
 	// The CometOrbit is in fact available in userDataPtr!
 	CometOrbit* orbit=(CometOrbit*)userDataPtr;
 	Q_ASSERT(orbit);
-	if (!orbit->objectDateValid(core->getJDay())) return; // out of useful date range. This allows having hundreds of comet elements.
-
-	if (orbit->getUpdateTails()){
-		// Compute lengths and orientations from orbit object, but only if required.
-		// TODO: This part should possibly be moved to another thread to keep draw() free from too much computation.
-
-		Vec2f tailFactors=getComaDiameterAndTailLengthAU();
-		float gasTailEndRadius=qMax(tailFactors[0], 0.025f*tailFactors[1]) ; // This avoids too slim gas tails for bright comets like Hale-Bopp.
-		float gasparameter=gasTailEndRadius*gasTailEndRadius/(2.0f*tailFactors[1]); // parabola formula: z=r²/2p, so p=r²/2z
-		// The dust tail is thicker and usually shorter. The factors can be configured in the elements.
-		float dustparameter=gasTailEndRadius*gasTailEndRadius*dustTailWidthFactor*dustTailWidthFactor/(2.0f*dustTailLengthFactor*tailFactors[1]);
-
-		// Find valid parameters to create paraboloid vertex arrays: dustTail, gasTail.
-		computeParabola(gasparameter, gasTailEndRadius, -0.5f*gasparameter, gastailVertexArr,  gastailTexCoordArr, gastailIndices);
-		// This was for a rotated straight parabola:
-		//computeParabola(dustparameter, 2.0f*tailFactors[0], -0.5f*dustparameter, dusttailVertexArr, dusttailTexCoordArr, dusttailIndices);
-		// Now we make a skewed parabola. Skew factor 15 (last arg) ad-hoc/empirical. TBD later: Find physically correct solution.
-		computeParabola(dustparameter, dustTailWidthFactor*gasTailEndRadius, -0.5f*dustparameter, dusttailVertexArr, gastailTexCoordArr, gastailIndices, 25.0f*orbit->getVelocity().length());
-
-		// Note that we use a diameter larger than what the formula returns. A scale factor of 1.2 is ad-hoc/empirical (GZ), but may look better.
-		computeComa(1.0f*tailFactors[0]);
-		orbit->setUpdateTails(false); // don't update until position has been recalculated elsewhere
-	}
+	if (!orbit->objectDateValid(core->getJDay())) return; // don't draw at all out of useful date range. This allows having hundreds of comet elements.
 
 	Mat4d mat = Mat4d::translation(eclipticPos) * rotLocalToParent;
-/*  // We can remove that - a Comet has no parent except for the sun...
-	PlanetP p = parent;
-	while (p && p->parent)
-	{
-		mat = Mat4d::translation(p->eclipticPos) * mat * p->rotLocalToParent;
-		p = p->parent;
-	}
-*/
 	// This removed totally the Planet shaking bug!!!
 	StelProjector::ModelViewTranformP transfo = core->getHeliocentricEclipticModelViewTransform();
 	transfo->combine(mat);
@@ -358,10 +408,12 @@ void Comet::draw(StelCore* core, float maxMagLabels, const QFont& planetNameFont
 
 		draw3dModel(core,transfo,screenSz);
 	}
-	// tails should also be drawn if core is off-screen...
-	drawTail(core,transfo,true);  // gas tail
-	drawTail(core,transfo,false); // dust tail
-
+	// tails should also be drawn if comet core is off-screen...
+	if (tailActive)
+	{
+		drawTail(core,transfo,true);  // gas tail
+		drawTail(core,transfo,false); // dust tail
+	}
 	//Coma: this is just a fan disk tilted towards the observer;-)
 	drawComa(core, transfo);
 	return;
@@ -369,25 +421,7 @@ void Comet::draw(StelCore* core, float maxMagLabels, const QFont& planetNameFont
 
 void Comet::drawTail(StelCore* core, StelProjector::ModelViewTranformP transfo, bool gas)
 {
-	// Find rotation matrix from 0/0/1 to eclipticPosition: crossproduct for axis (normal vector), dotproduct for angle.
-	Vec3d eclposNrm=eclipticPos; eclposNrm.normalize();
-	Mat4d tailrot=Mat4d::rotation(Vec3d(0.0, 0.0, 1.0)^(eclposNrm), std::acos(Vec3d(0.0, 0.0, 1.0).dot(eclposNrm)) );
-
-	StelProjector::ModelViewTranformP transfo2 = transfo->clone();
-	transfo2->combine(tailrot);
-	if (!gas) {
-		CometOrbit* orbit=(CometOrbit*)userDataPtr;
-		Vec3d velocity=orbit->getVelocity(); // [AU/d]
-		// This was a try to rotate a straight parabola somewhat away from the antisolar direction.
-		//Mat4d dustTailRot=Mat4d::rotation(eclposNrm^(-velocity), 0.15f*std::acos(eclposNrm.dot(-velocity))); // GZ: This scale factor of 0.15 is empirical from photos of Halley and Hale-Bopp.
-		// The curved tail is curved towards positive X. We first rotate around the Z axis into a direction opposite of the motion vector, then again the antisolar rotation applies.
-		Mat4d dustTailRot=Mat4d::zrotation(atan2(velocity[1], velocity[0]) + M_PI);
-		transfo2->combine(dustTailRot);
-		// In addition, we let the dust tail already start with a light tilt.
-		Mat4d dustTailYrot=Mat4d::yrotation(5.0f*velocity.length()); // again, this is pretty ad-hoc, feel free to improve!
-		transfo2->combine(dustTailYrot);
-	}
-	StelPainter* sPainter = new StelPainter(core->getProjection(transfo2));
+	StelPainter* sPainter = new StelPainter(core->getProjection(transfo));
 	glEnable(GL_BLEND);
 	glBlendFunc(GL_ONE, GL_ONE);
 	glDisable(GL_CULL_FACE);
@@ -395,7 +429,6 @@ void Comet::drawTail(StelCore* core, StelProjector::ModelViewTranformP transfo,
 	// GZ: If we use getVMagnitudeWithExtinction(), a head extincted in the horizon mist can completely hide an otherwise frighteningly long tail.
 	// we must use unextincted mag, but mix/dim with atmosphere/sky brightness.
 	// In addition, light falloff is a bit reduced for better visibility. Power basis should be 0.4, we use 0.6.
-	//float magfactor=std::pow(0.4f , getVMagnitudeWithExtinction(core));
 	float magFactor=std::pow(0.6f , getVMagnitude(core));
 	if (core->getSkyDrawer()->getFlagHasAtmosphere())
 	{
@@ -411,21 +444,17 @@ void Comet::drawTail(StelCore* core, StelProjector::ModelViewTranformP transfo,
 	magFactor*=(gas? 0.9 : dustTailBrightnessFactor); // TBD: empirical adjustment for texture brightness.
 	magFactor=qMin(magFactor, 1.05f); // Limit excessively bright display.
 
-	gasTailTexture->bind();
+	tailTexture->bind();
 
 	if (gas) {
-		//gasTailTexture->bind();
 		sPainter->setColor(0.15f*magFactor,0.15f*magFactor,0.6f*magFactor);
-		sPainter->setArrays((Vec3d*)gastailVertexArr.constData(), (Vec2f*)gastailTexCoordArr.constData());
-		sPainter->drawFromArray(StelPainter::Triangles, gastailIndices.size(), 0, true, gastailIndices.constData());
+		sPainter->setArrays((Vec3d*)gastailVertexArr.constData(), (Vec2f*)tailTexCoordArr.constData());
+		sPainter->drawFromArray(StelPainter::Triangles, tailIndices.size(), 0, true, tailIndices.constData());
 
 	} else {
-		//dustTailTexture->bind();
 		sPainter->setColor(magFactor, magFactor,0.6f*magFactor);
-		//sPainter->setArrays((Vec3d*)dusttailVertexArr.constData(), (Vec2f*)dusttailTexCoordArr.constData());
-		//sPainter->drawFromArray(StelPainter::Triangles, dusttailIndices.size(), 0, true, dusttailIndices.constData());
-		sPainter->setArrays((Vec3d*)dusttailVertexArr.constData(), (Vec2f*)gastailTexCoordArr.constData());
-		sPainter->drawFromArray(StelPainter::Triangles, gastailIndices.size(), 0, true, gastailIndices.constData());
+		sPainter->setArrays((Vec3d*)dusttailVertexArr.constData(), (Vec2f*)tailTexCoordArr.constData());
+		sPainter->drawFromArray(StelPainter::Triangles, tailIndices.size(), 0, true, tailIndices.constData());
 	}
 	glDisable(GL_BLEND);
 
@@ -470,7 +499,7 @@ void Comet::drawComa(StelCore* core, StelProjector::ModelViewTranformP transfo)
 }
 
 // Formula found at http://www.projectpluto.com/update7b.htm#comet_tail_formula
-Vec2f Comet::getComaDiameterAndTailLengthAU() const
+Vec2f Comet::getComaDiameterAndTailLengthAU()
 {
 	float r = getHeliocentricEclipticPos().length();
 	float mhelio = absoluteMagnitude + slopeParameter * log10(r);
@@ -493,11 +522,12 @@ void Comet::computeComa(const float diameter)
 // xOffset for the dust tail, this may introduce a bend. Units are x per sqrt(z).
 void Comet::computeParabola(const float parameter, const float radius, const float zshift,
 			    QVector<double>& vertexArr, QVector<float>& texCoordArr, QVector<unsigned short> &indices, const float xOffset) {
-	vertexArr.clear();
-	//texCoordArr.clear();
-	//indices.clear();
-	bool createIndices= indices.empty();
-	bool createTexcoords= texCoordArr.empty();
+
+	// GZ: keep the array and replace contents. However, using replace() is only slightly faster.
+	if (vertexArr.length() < (3*(COMET_TAIL_SLICES*COMET_TAIL_STACKS+1)))
+		vertexArr.resize(3*(COMET_TAIL_SLICES*COMET_TAIL_STACKS+1));
+	if (createTailIndices) indices.clear();
+	if (createTailTextureCoords) texCoordArr.clear();
 	int i;
 	// The parabola has triangular faces with vertices on two circles that are rotated against each other. 
 	float xa[2*COMET_TAIL_SLICES];
@@ -511,9 +541,9 @@ void Comet::computeParabola(const float parameter, const float radius, const flo
 		ya[i]=cos(i*da);
 	}
 	
-	// center point, vertex0
-	vertexArr << 0.0f << 0.0f << zshift;
-	if (createTexcoords) texCoordArr << 0.5f << 0.5f;
+	vertexArr.replace(0, 0.0); vertexArr.replace(1, 0.0); vertexArr.replace(2, zshift);
+	int vertexArrIndex=3;
+	if (createTailTextureCoords) texCoordArr << 0.5f << 0.5f;
 	// define the indices lying on circles, starting at 1: odd rings have 1/slices+1/2slices, even-numbered rings straight 1/slices
 	// inner ring#1
 	int ring;
@@ -523,12 +553,14 @@ void Comet::computeParabola(const float parameter, const float radius, const flo
 		for (i=ring & 1; i<2*COMET_TAIL_SLICES; i+=2) { // i.e., ring1 has shifted vertices, ring2 has even ones.
 			x=xa[i]*radius*ring/COMET_TAIL_STACKS;
 			y=ya[i]*radius*ring/COMET_TAIL_STACKS;
-			vertexArr << x+xShift << y << z;
-			if (createTexcoords) texCoordArr << 0.5+ 0.5*x/radius << 0.5+0.5*y/radius;
+			vertexArr.replace(vertexArrIndex++, x+xShift);
+			vertexArr.replace(vertexArrIndex++, y);
+			vertexArr.replace(vertexArrIndex++, z);
+			if (createTailTextureCoords) texCoordArr << 0.5+ 0.5*x/radius << 0.5+0.5*y/radius;
 		}
 	}
-	// now link the faces with indices. That's fun... ;-)
-	if (createIndices)
+	// now link the faces with indices.
+	if (createTailIndices)
 	{
 		for (i=1; i<COMET_TAIL_SLICES; ++i) indices << 0 << i << i+1;
 		indices << 0 << COMET_TAIL_SLICES << 1; // close inner fan.
@@ -555,11 +587,14 @@ void Comet::computeParabola(const float parameter, const float radius, const flo
 			indices << first << (ring+1)*COMET_TAIL_SLICES << ring*COMET_TAIL_SLICES+1;
 		}
 	}
-//	qDebug() << "Parabola: Vertex index dump\n";
-//	for (int i=0; i<indices.length(); i+=3)
-//		qDebug() << indices[i] << "-" << indices[i+1] << "-" << indices[i+2] << ":"
-//				 << vertexArr[3*indices[i]]   << vertexArr[3*indices[i]+1]   << vertexArr[3*indices[i]+2]   << "/"
-//				 << vertexArr[3*indices[i+1]] << vertexArr[3*indices[i+1]+1] << vertexArr[3*indices[i+1]+2] << "/"
-//				 << vertexArr[3*indices[i+2]] << vertexArr[3*indices[i+2]+1] << vertexArr[3*indices[i+2]+2];
-
+	createTailIndices=false;
+	createTailTextureCoords=false;
 }
+
+// These are to avoid having index arrays for each comet when all are equal.
+bool Comet::createTailIndices=true;
+bool Comet::createTailTextureCoords=true;
+StelTextureSP Comet::comaTexture;
+StelTextureSP Comet::tailTexture;
+QVector<float> Comet::tailTexCoordArr; // computed only once FOR ALL COMETS!
+QVector<unsigned short> Comet::tailIndices; // computed only once FOR ALL COMETS!
