@@ -1,6 +1,7 @@
 /*
  * Stellarium
  * Copyright (C) 2010 Bogdan Marinov
+ * Copyright (C) 2014 Georg Zotti (orbit fix, tails, speedup)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -28,29 +29,31 @@
 	Some of the code in this class is re-used from the parent Planet class.
 	\todo Implement better comet rendering (star-like objects, no physical body).
 	\todo (Long-term) Photo realistic comet rendering, see https://blueprints.launchpad.net/stellarium/+spec/realistic-comet-rendering
-	2013-12: New algorithms for position computation following Paul Heafner: Fundamental Ephemeris Computations (Willmann-Bell 1999).
-	2014-01: Parabolic tails appropriately scaled/rotated. Much is currently empirical, leaving room for physics-based improvements.
+	2013-12: GZ: New algorithms for position computation following Paul Heafner: Fundamental Ephemeris Computations (Willmann-Bell 1999).
+	2014-01: GZ: Parabolic tails appropriately scaled/rotated. Much is currently empirical, leaving room for physics-based improvements.
+	2014-08: GZ: speedup in case hundreds of comets are loaded.
   */
 class Comet : public Planet
 {
 public:
+	friend class SolarSystem;               // Solar System initializes static constants.
 	Comet(const QString& englishName,
-	       int flagLighting,
-	       double radius,
-	       double oblateness,
-	       Vec3f color,
-	       float albedo,
-	       const QString& texMapName,
-	       posFuncType _coordFunc,
-	       void* userDataPtr,
-	       OsculatingFunctType *osculatingFunc,
-	       bool closeOrbit,
-	       bool hidden,
-		   const QString &pType,
-		   float dustTailWidthFact=1.5f,
-		   float dustTailLengthFact=0.4f,
-		   float dustTailBrightnessFact=1.5f
-		  );
+	      int flagLighting,
+	      double radius,
+	      double oblateness,
+	      Vec3f color,
+	      float albedo,
+	      const QString& texMapName,
+	      posFuncType _coordFunc,
+	      void* userDataPtr,
+	      OsculatingFunctType *osculatingFunc,
+	      bool closeOrbit,
+	      bool hidden,
+	      const QString &pTypeStr,
+	      float dustTailWidthFact=1.5f,
+	      float dustTailLengthFact=0.4f,
+	      float dustTailBrightnessFact=1.5f
+	);
 
 	virtual ~Comet();
 
@@ -87,13 +90,16 @@ public:
 	//! get sidereal period for comet, days, or returns 0 if not possible (paraboloid, hyperboloid orbit)
 	virtual double getSiderealPeriod() const;
 
+	//! GZ: override from Planet: extend with tail details.
+	virtual void computePosition(const double date);
+
 	//! re-implementation of Planet's draw()
 	virtual void draw(StelCore* core, float maxMagLabels, const QFont& planetNameFont);
 
 private:
 	//! @returns estimates for (Coma diameter [AU], gas tail length [AU]).
 	//! Using the formula from Guide found by the GSoC2012 initiative at http://www.projectpluto.com/update7b.htm#comet_tail_formula
-	Vec2f getComaDiameterAndTailLengthAU() const;
+	Vec2f getComaDiameterAndTailLengthAU();
 	void drawTail(StelCore* core, StelProjector::ModelViewTranformP transfo, bool gas);
 	void drawComa(StelCore* core, StelProjector::ModelViewTranformP transfo);
 
@@ -120,20 +126,28 @@ private:
 	bool nameIsProvisionalDesignation;
 
 	//GZ Tail additions
+	Vec2f tailFactors; // result of latest call to getComaDiameterAndTailLengthAU(); Results cached here for infostring. [0]=Coma diameter, [1] gas tail length.
+	bool tailActive;		//! true if there is a tail worth bothering (longer than COMET_MIN_TAIL_LENGTH_AU)? Drawing tails is quite costly.
+	double deltaJDtail;             //! like deltaJD, but time difference between tail geometry updates.
+	double lastJDtail;             //! like lastJD, but time of last tail geometry update.
+	Mat4d gasTailRot;		//! rotation matrix for gas tail parabola
+	Mat4d dustTailRot;		//! rotation matrix for the skewed dust tail parabola
 	float dustTailWidthFactor;      //!< empirical individual broadening of the dust tail end, compared to the gas tail end. Actually, dust tail width=2*comaWidth*dustTailWidthFactor. Default 1.5
 	float dustTailLengthFactor;     //!< empirical individual length of dust tail relative to gas tail. Taken from ssystem.ini, typical value 0.3..0.5, default 0.4
 	float dustTailBrightnessFactor; //!< empirical individual brightness of dust tail relative to gas tail. Taken from ssystem.ini, default 1.5
+	QVector<double> comaVertexArr;
+	QVector<float> comaTexCoordArr; //  --> 2014-08: could also be declared static, but it is filled by StelPainter...
+
+	// These are to avoid having index arrays for each comet when all are equal.
+	static bool createTailIndices;
+	static bool createTailTextureCoords;
+
 	QVector<double> gastailVertexArr;  // computed frequently, describes parabolic shape (along z axis) of gas tail.
 	QVector<double> dusttailVertexArr; // computed frequently, describes parabolic shape (along z axis) of dust tail.
-	QVector<float> gastailTexCoordArr; // computed only once per comet!
-	//QVector<float> dusttailTexCoordArr; // currently identical to gastailVertexArr, has been taken out.
-	QVector<unsigned short> gastailIndices; // computed only once per comet!
-	//QVector<unsigned short> dusttailIndices; // actually no longer required. Re-use gas tail indices.
-	QVector<double> comaVertexArr;
-	QVector<float> comaTexCoordArr;
-	StelTextureSP comaTexture;
-	StelTextureSP gasTailTexture;
-	//StelTextureSP dusttailTexture;  // it seems not really necessary to have different textures.
+	static QVector<float> tailTexCoordArr; // computed only once for all comets!
+	static QVector<unsigned short> tailIndices; // computed only once for all comets!
+	static StelTextureSP comaTexture;
+	static StelTextureSP tailTexture;      // it seems not really necessary to have different textures. gas tail is just painted blue.
 };
 
 #endif //_COMET_HPP_
