@@ -37,6 +37,7 @@ Vec3f Constellation::lineColor = Vec3f(0.4,0.4,0.8);
 Vec3f Constellation::labelColor = Vec3f(0.4,0.4,0.8);
 Vec3f Constellation::boundaryColor = Vec3f(0.8,0.3,0.3);
 bool Constellation::singleSelected = false;
+bool Constellation::seasonalRuleEnabled = false;
 
 Constellation::Constellation()
 	: numberOfSegments(0)
@@ -103,17 +104,20 @@ void Constellation::drawOptim(StelPainter& sPainter, const StelCore* core, const
 	if (lineFader.getInterstate()<=0.0001f)
 		return;
 
-	sPainter.setColor(lineColor[0], lineColor[1], lineColor[2], lineFader.getInterstate());
-
-	Vec3d star1;
-	Vec3d star2;
-	for (unsigned int i=0;i<numberOfSegments;++i)
+	if (checkVisibility())
 	{
-		star1=asterism[2*i]->getJ2000EquatorialPos(core);
-		star2=asterism[2*i+1]->getJ2000EquatorialPos(core);
-		star1.normalize();
-		star2.normalize();
-		sPainter.drawGreatCircleArc(star1, star2, &viewportHalfspace);
+		sPainter.setColor(lineColor[0], lineColor[1], lineColor[2], lineFader.getInterstate());
+
+		Vec3d star1;
+		Vec3d star2;
+		for (unsigned int i=0;i<numberOfSegments;++i)
+		{
+			star1=asterism[2*i]->getJ2000EquatorialPos(core);
+			star2=asterism[2*i+1]->getJ2000EquatorialPos(core);
+			star1.normalize();
+			star2.normalize();
+			sPainter.drawGreatCircleArc(star1, star2, &viewportHalfspace);
+		}
 	}
 }
 
@@ -121,22 +125,29 @@ void Constellation::drawName(StelPainter& sPainter) const
 {
 	if (!nameFader.getInterstate())
 		return;
-	sPainter.setColor(labelColor[0], labelColor[1], labelColor[2], nameFader.getInterstate());
-	sPainter.drawText(XYname[0], XYname[1], nameI18, 0., -sPainter.getFontMetrics().width(nameI18)/2, 0, false);
+
+	if (checkVisibility())
+	{
+		sPainter.setColor(labelColor[0], labelColor[1], labelColor[2], nameFader.getInterstate());
+		sPainter.drawText(XYname[0], XYname[1], nameI18, 0., -sPainter.getFontMetrics().width(nameI18)/2, 0, false);
+	}
 }
 
 void Constellation::drawArtOptim(StelPainter& sPainter, const SphericalRegion& region) const
 {
-	const float intensity = artFader.getInterstate();
-	if (artTexture && intensity && region.intersects(boundingCap))
+	if (checkVisibility())
 	{
-		sPainter.setColor(intensity,intensity,intensity);
+		const float intensity = artFader.getInterstate();
+		if (artTexture && intensity && region.intersects(boundingCap))
+		{
+			sPainter.setColor(intensity,intensity,intensity);
 
-		// The texture is not fully loaded
-		if (artTexture->bind()==false)
-			return;
+			// The texture is not fully loaded
+			if (artTexture->bind()==false)
+				return;
 
-		sPainter.drawStelVertexArray(artPolygon);
+			sPainter.drawStelVertexArray(artPolygon);
+		}
 	}
 }
 
@@ -215,6 +226,32 @@ void Constellation::drawBoundaryOptim(StelPainter& sPainter) const
 	}
 }
 
+bool Constellation::checkVisibility() const
+{
+	// Is supported seasonal rules by current starlore?
+	if (!seasonalRuleEnabled)
+		return true;
+
+	bool visible = false;
+	int year, month, day;
+	// Get the current month
+	StelUtils::getDateFromJulianDay(StelApp::getInstance().getCore()->getJDay(), &year, &month, &day);
+	if (endSeason >= beginSeason)
+	{
+		// OK, it's a "normal" season rule...
+		if ((month >= beginSeason) && (month <= endSeason))
+			visible = true;
+	}
+	else
+	{
+		// ...oops, it's a "inverted" season rule
+		if (((month>=1) && (month<=endSeason)) || ((month>=beginSeason) && (month<=12)))
+			visible = true;
+
+	}
+	return visible;
+}
+
 StelObjectP Constellation::getBrightestStarInConstellation(void) const
 {
 	float maxMag = 99.f;
