@@ -72,7 +72,8 @@ private:
 
 Cardinals::Cardinals(float _radius) : radius(_radius), color(0.6,0.2,0.2)
 {
-	font.setPixelSize(30);
+	// Font size is 30
+	font.setPixelSize(StelApp::getInstance().getBaseFontSize()+17);
 	// Default labels - if sky locale specified, loaded later
 	// Improvement for gettext translation
 	sNorth = "N";
