@@ -1,7 +1,8 @@
 /*
  * Stellarium
- * This file Copyright (C) 2004 Robert Spearman
- * 
+ * Copyright (C) 2004 Robert Spearman
+ * Copyright (C) 2014 Marcos Cardinot
+ *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
  * as published by the Free Software Foundation; either version 2
@@ -17,46 +18,44 @@
  * Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA  02110-1335, USA.
  */
 
-#include <functional>
-#include <cstdlib>
-#include <QSettings>
-
 #include "LandscapeMgr.hpp"
 #include "Meteor.hpp"
 #include "MeteorMgr.hpp"
-#include "renderer/StelRenderer.hpp"
+#include "SolarSystem.hpp"
 #include "StelApp.hpp"
 #include "StelCore.hpp"
+#include "StelFileMgr.hpp"
 #include "StelModuleMgr.hpp"
-#include "StelProjector.hpp"
+#include "StelPainter.hpp"
+#include "StelTextureMgr.hpp"
 
-MeteorMgr::MeteorMgr(int zhr, int maxv ) : flagShow(true)
+#include <QSettings>
+
+const double MeteorMgr::zhrToWsr = 1.6667f / 3600.f;
+
+MeteorMgr::MeteorMgr(int zhr, int maxv )
+	: ZHR(zhr)
+	, maxVelocity(maxv)
+	, flagShow(true)
 {
 	setObjectName("MeteorMgr");
-			
-	ZHR = zhr;
-	maxVelocity = maxv;
-
-	// calculate factor for meteor creation rate per second since visible area ZHR is for
-	// estimated visible radius of 458km
-	// (calculated for average meteor magnitude of +2.5 and limiting magnitude of 5)
-
-	//  zhrToWsr = 1.0f/3600.f;
-	zhrToWsr = 1.6667f/3600.f;
-	// this is a correction factor to adjust for the model as programmed to match observed rates
 }
 
 MeteorMgr::~MeteorMgr()
 {
-	for(std::vector<Meteor*>::iterator iter = active.begin(); iter != active.end(); ++iter)
+	std::vector<Meteor*>::iterator iter;
+	for(iter = active.begin(); iter != active.end(); ++iter)
 	{
 		delete *iter;
 	}
 	active.clear();
+	Meteor::bolideTexture.clear();
 }
 
 void MeteorMgr::init()
 {
+	Meteor::bolideTexture = StelApp::getInstance().getTextureManager().createTextureThread(StelFileMgr::getInstallationDir()+"/textures/cometComa.png", StelTexture::StelTextureParams(true, GL_LINEAR, GL_CLAMP_TO_EDGE));
+
 	setZHR(StelApp::getInstance().getSettings()->value("astro/meteor_rate", 10).toInt());
 }
 
@@ -66,7 +65,9 @@ void MeteorMgr::init()
 double MeteorMgr::getCallOrder(StelModuleActionName actionName) const
 {
 	if (actionName==StelModule::ActionDraw)
-		return StelApp::getInstance().getModuleMgr().getModule("SolarSystem")->getCallOrder(actionName)+10;
+	{
+		return GETSTELMODULE(SolarSystem)->getCallOrder(actionName)+10.;
+	}
 	return 0;
 }
 
@@ -92,76 +93,83 @@ void MeteorMgr::update(double deltaTime)
 	return;
 #endif
 	if (!flagShow)
+	{
 		return;
-	
-	deltaTime*=1000;
+	}
+
 	StelCore* core = StelApp::getInstance().getCore();
 
+	double tspeed = core->getTimeRate()*86400;  // sky seconds per actual second
+	if (!tspeed) { // is paused?
+		return; // freeze meteors at the current position
+	}
+
+	deltaTime*=1000;
+	// if stellarium has been suspended, don't create
+	// huge number of meteors to make up for lost time!
+	if (deltaTime > 500)
+	{
+		deltaTime = 500;
+	}
+
 	// step through and update all active meteors
-	for (std::vector<Meteor*>::iterator iter = active.begin(); iter != active.end(); ++iter)
+	std::vector<Meteor*>::iterator iter;
+	for (iter = active.begin(); iter != active.end(); ++iter)
 	{
 		if (!(*iter)->update(deltaTime))
 		{
-			// remove dead meteor
-			//      qDebug("Meteor \tdied\n");
-
 			delete *iter;
-			active.erase(iter);
+			iter = active.erase(iter);
 			iter--;  // important!
 		}
 	}
 
 	// only makes sense given lifetimes of meteors to draw when timeSpeed is realtime
 	// otherwise high overhead of large numbers of meteors
-	double tspeed = core->getTimeRate()*86400;  // sky seconds per actual second
-	if (tspeed<=0 || fabs(tspeed)>1.)
+	if (tspeed<0 || fabs(tspeed)>1.)
 	{
 		// don't start any more meteors
 		return;
 	}
 
-	// if stellarium has been suspended, don't create huge number of meteors to
-	// make up for lost time!
-	if (deltaTime > 500)
-	{
-		deltaTime = 500;
-	}
-
 	// determine average meteors per frame needing to be created
 	int mpf = (int)((double)ZHR*zhrToWsr*deltaTime/1000.0 + 0.5);
 	if (mpf<1)
+	{
 		mpf = 1;
+	}
 
-	int mlaunch = 0;
 	for (int i=0; i<mpf; ++i)
 	{
 		// start new meteor based on ZHR time probability
 		double prob = ((double)rand())/RAND_MAX;
-		if (ZHR>0 && prob<((double)ZHR*zhrToWsr*deltaTime/1000.0/(double)mpf) )
+		if (ZHR>0 && prob<((double)ZHR*zhrToWsr*deltaTime/1000.0/(double)mpf))
 		{
-			Meteor *m = new Meteor(StelApp::getInstance().getCore(), maxVelocity);
+			Meteor *m = new Meteor(core, maxVelocity);
 			active.push_back(m);
-			mlaunch++;
 		}
 	}
-	//  qDebug("mpf: %d\tm launched: %d\t(mps: %f)\t%d\n", mpf, mlaunch, ZHR*zhrToWsr, deltaTime);
 }
 
 
-void MeteorMgr::draw(StelCore* core, StelRenderer* renderer)
+void MeteorMgr::draw(StelCore* core)
 {
 	if (!flagShow)
+	{
 		return;
-	
-	LandscapeMgr* landmgr = (LandscapeMgr*)StelApp::getInstance().getModuleMgr().getModule("LandscapeMgr");
-	if (landmgr->getFlagAtmosphere() && landmgr->getLuminance()>5)
-		return;
+	}
 
-	renderer->setBlendMode(BlendMode_Alpha);
+	LandscapeMgr* landmgr = GETSTELMODULE(LandscapeMgr);
+	if (landmgr->getFlagAtmosphere() && landmgr->getLuminance()>5)
+	{
+		return;
+	}
 
 	// step through and draw all active meteors
-	for (std::vector<Meteor*>::iterator iter = active.begin(); iter != active.end(); ++iter)
+	StelPainter sPainter(core->getProjection(StelCore::FrameAltAz));
+	std::vector<Meteor*>::iterator iter;
+	for (iter = active.begin(); iter != active.end(); ++iter)
 	{
-		(*iter)->draw(core, core->getProjection(StelCore::FrameAltAz), renderer);
+		(*iter)->draw(core, sPainter);
 	}
 }
