@@ -19,25 +19,26 @@
 
 #include "MilkyWay.hpp"
 #include "StelFader.hpp"
-#include "renderer/StelGeometryBuilder.hpp"
-#include "renderer/StelRenderer.hpp"
-#include "renderer/StelTextureNew.hpp"
+#include "StelTexture.hpp"
 #include "StelUtils.hpp"
+#include "StelFileMgr.hpp"
 
 #include "StelProjector.hpp"
 #include "StelToneReproducer.hpp"
 #include "StelApp.hpp"
+#include "StelTextureMgr.hpp"
 #include "StelCore.hpp"
 #include "StelSkyDrawer.hpp"
+#include "StelPainter.hpp"
 
 #include <QDebug>
 #include <QSettings>
 
 // Class which manages the displaying of the Milky Way
-MilkyWay::MilkyWay() 
-	: tex(NULL)
-	, color(1.f, 1.f, 1.f)
-	, skySphere(NULL)
+MilkyWay::MilkyWay()
+	: color(1.f, 1.f, 1.f)
+	, intensity(1.)
+	, vertexArray()
 {
 	setObjectName("MilkyWay");
 	fader = new LinearFader();
@@ -48,16 +49,8 @@ MilkyWay::~MilkyWay()
 	delete fader;
 	fader = NULL;
 	
-	if(NULL != tex)
-	{
-		delete tex;
-		tex = NULL;
-	}
-	if(NULL != skySphere)
-	{
-		delete skySphere;
-		skySphere = NULL;
-	}
+	delete vertexArray;
+	vertexArray = NULL;
 }
 
 void MilkyWay::init()
@@ -65,11 +58,11 @@ void MilkyWay::init()
 	QSettings* conf = StelApp::getInstance().getSettings();
 	Q_ASSERT(conf);
 
+	tex = StelApp::getInstance().getTextureManager().createTexture(StelFileMgr::getInstallationDir()+"/textures/milkyway.png");
 	setFlagShow(conf->value("astro/flag_milky_way").toBool());
 	setIntensity(conf->value("astro/milky_way_intensity",1.f).toFloat());
 
-	const SphereParams params = SphereParams(1.0f).resolution(20, 20).orientInside();
-	skySphere = StelGeometryBuilder().buildSphereUnlit(params);
+	vertexArray = new StelVertexArray(StelPainter::computeSphereNoLight(1.f,1.f,20,20,1));
 }
 
 
@@ -78,53 +71,46 @@ void MilkyWay::update(double deltaTime) {fader->update((int)(deltaTime*1000));}
 void MilkyWay::setFlagShow(bool b){*fader = b;}
 bool MilkyWay::getFlagShow() const {return *fader;}
 
-void MilkyWay::draw(StelCore* core, class StelRenderer* renderer)
+void MilkyWay::draw(StelCore* core)
 {
 	if (!getFlagShow())
 		return;
 
 	StelProjector::ModelViewTranformP transfo = core->getJ2000ModelViewTransform();
 	transfo->combine(Mat4d::xrotation(M_PI/180.*23.)*
-	                 Mat4d::yrotation(M_PI/180.*120.)*
-	                 Mat4d::zrotation(M_PI/180.*7.));
-
-	if(NULL == tex)
-	{
-		tex = renderer->createTexture("textures/milkyway.png");
-	}
+					 Mat4d::yrotation(M_PI/180.*120.)*
+					 Mat4d::zrotation(M_PI/180.*7.));
 
 	const StelProjectorP prj = core->getProjection(transfo);
 	StelToneReproducer* eye = core->getToneReproducer();
 
-	Q_ASSERT_X(NULL != tex, Q_FUNC_INFO, "A texture must be loaded before calling this");
+	Q_ASSERT(tex);	// A texture must be loaded before calling this
 
-	// This color corresponds to the night blue scotopic color = 0.25, 0.25 in xyY mode.
+	// This RGB color corresponds to the night blue scotopic color = 0.25, 0.25 in xyY mode.
 	// since milky way is always seen white RGB value in the texture (1.0,1.0,1.0)
-	Vec4f c = StelApp::getInstance().getVisionModeNight() 
-	        ? Vec4f(0.34165f, 0.0f, 0.0f, 1.0f)
-	        : Vec4f(0.34165f, 0.429666f, 0.63586f, 1.0f);
+	Vec3f c = Vec3f(0.34165f, 0.429666f, 0.63586f);
 
-	const float lum = core->getSkyDrawer()->surfacebrightnessToLuminance(13.5f);
+	float lum = core->getSkyDrawer()->surfacebrightnessToLuminance(13.5f);
 
 	// Get the luminance scaled between 0 and 1
-	float aLum = eye->adaptLuminanceScaled(lum*fader->getInterstate());
+	float aLum =eye->adaptLuminanceScaled(lum*fader->getInterstate());
 
 	// Bound a maximum luminance
-	aLum = qMin(0.38f, aLum * 2.0f);
+	aLum = qMin(0.38f, aLum*2.f);
 
 	// intensity of 1.0 is "proper", but allow boost for dim screens
-	c *= aLum * intensity;
+	c*=aLum*intensity;
 
-	c[0] = std::max(c[0], 0.0f);
-	c[1] = std::max(c[1], 0.0f);
-	c[2] = std::max(c[2], 0.0f);
-	c[3] = 1.0f;
+	if (c[0]<0) c[0]=0;
+	if (c[1]<0) c[1]=0;
+	if (c[2]<0) c[2]=0;
 
-	renderer->setGlobalColor(c[0], c[1], c[2]);
-	renderer->setCulledFaces(CullFace_Back);
-	renderer->setBlendMode(BlendMode_None);
+	StelPainter sPainter(prj);
+	sPainter.setColor(c[0],c[1],c[2]);
+	glEnable(GL_CULL_FACE);
+	sPainter.enableTexture2d(true);
+	glDisable(GL_BLEND);
 	tex->bind();
-
-	skySphere->draw(renderer, prj);
-	renderer->setCulledFaces(CullFace_None);
+	sPainter.drawStelVertexArray(*vertexArray);
+	glDisable(GL_CULL_FACE);
 }
