@@ -1,6 +1,7 @@
 /*
  * Stellarium
  * Copyright (C) 2010 Bogdan Marinov
+ * Copyright (C) 2013-14 Georg Zotti (accuracy&speedup)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -49,7 +50,7 @@ public:
 		    OsculatingFunctType *osculatingFunc,
 		    bool closeOrbit,
 		    bool hidden,
-		    const QString &pType);
+		    const QString &pTypeStr);
 
 	~MinorPlanet();
 
@@ -110,8 +111,8 @@ public:
 
 private:
 	int minorPlanetNumber;
-	double absoluteMagnitude;
-	double slopeParameter;
+	float absoluteMagnitude;
+	float  slopeParameter;
 	double semiMajorAxis;
 
 	bool nameIsProvisionalDesignation;
