@@ -69,7 +69,7 @@ SolarSystem::SolarSystem()
 	, flagMarker(false)
 	, allTrails(NULL)
 {
-	planetNameFont.setPixelSize(StelApp::getInstance().getSettings()->value("gui/base_font_size", 13).toInt());
+	planetNameFont.setPixelSize(StelApp::getInstance().getBaseFontSize());
 	setObjectName("SolarSystem");
 }
 
@@ -119,6 +119,7 @@ void SolarSystem::init()
 	QSettings* conf = StelApp::getInstance().getSettings();
 	Q_ASSERT(conf);
 
+	Planet::init();
 	loadPlanets();	// Load planets data
 
 	// Compute position and matrix of sun and all the satellites (ie planets)
@@ -905,6 +906,12 @@ bool SolarSystem::loadPlanets(const QString& filePath)
 	// special case: load earth shadow texture
 	Planet::texEarthShadow = StelApp::getInstance().getTextureManager().createTexture(StelFileMgr::getInstallationDir()+"/textures/earth-shadow.png");
 
+	// GZ: Also comets just have static textures.
+	Comet::comaTexture = StelApp::getInstance().getTextureManager().createTextureThread(StelFileMgr::getInstallationDir()+"/textures/cometComa.png", StelTexture::StelTextureParams(true, GL_LINEAR, GL_CLAMP_TO_EDGE));
+	//GZ: tail textures. We use a paraboloid tail body, textured like a fisheye sphere, i.e. center=head. The texture should be something like a mottled star to give some structure.
+	Comet::tailTexture = StelApp::getInstance().getTextureManager().createTextureThread(StelFileMgr::getInstallationDir()+"/textures/cometTail.png", StelTexture::StelTextureParams(true, GL_LINEAR, GL_CLAMP_TO_EDGE));
+	//GZ: I think we need only one texture for the tails.
+
 	return true;
 }
 
@@ -1049,14 +1056,23 @@ StelObjectP SolarSystem::searchByName(const QString& name) const
 	return StelObjectP();
 }
 
-float SolarSystem::getPlanetVMagnitude(QString planetName) const
+float SolarSystem::getPlanetVMagnitude(QString planetName, bool withExtinction) const
 {
 	PlanetP p = searchByEnglishName(planetName);
 	float r = 0.f;
-	r = p->getVMagnitude(StelApp::getInstance().getCore());
+	if (withExtinction)
+		r = p->getVMagnitudeWithExtinction(StelApp::getInstance().getCore());
+	else
+		r = p->getVMagnitude(StelApp::getInstance().getCore());
 	return r;
 }
 
+QString SolarSystem::getPlanetType(QString planetName) const
+{
+	PlanetP p = searchByEnglishName(planetName);
+	return p->getPlanetTypeString();
+}
+
 double SolarSystem::getDistanceToPlanet(QString planetName) const
 {
 	PlanetP p = searchByEnglishName(planetName);
@@ -1360,21 +1376,23 @@ QStringList SolarSystem::listMatchingObjects(const QString& objPrefix, int maxNb
 	return result;
 }
 
-QStringList SolarSystem::listAllObjects(bool inEnglish) const
+QStringList SolarSystem::listAllObjectsByType(const QString &objType, bool inEnglish) const
 {
 	QStringList result;
 	if (inEnglish)
 	{
 		foreach(const PlanetP& p, systemPlanets)
 		{
-			result << p->getEnglishName();
+			if (p->getPlanetTypeString()==objType)
+				result << p->getEnglishName();
 		}
 	}
 	else
 	{
 		foreach(const PlanetP& p, systemPlanets)
 		{
-			result << p->getNameI18n();
+			if (p->getPlanetTypeString()==objType)
+				result << p->getNameI18n();
 		}
 	}
 	return result;
