@@ -122,7 +122,8 @@ public:
 	//! @param useStartOfWords the autofill mode for returned objects names.
 	//! @return a list of matching object name by order of relevance, or an empty list if nothing matches.
 	virtual QStringList listMatchingObjects(const QString& objPrefix, int maxNbItem=5, bool useStartOfWords=false) const;
-	virtual QStringList listAllObjects(bool inEnglish) const;
+	virtual QStringList listAllObjects(bool inEnglish) const { Q_UNUSED(inEnglish) return QStringList(); }
+	virtual QStringList listAllObjectsByType(const QString& objType, bool inEnglish) const;
 	virtual QString getName() const { return "Solar System"; }
 
 public slots:
@@ -233,7 +234,12 @@ public slots:
 	//! @param planetName the case in-sensistive English planet name.
 	//! @param withExtinction the flag for use extinction effect for magnitudes (default not use)
 	//! @return a magnitude
-	float getPlanetVMagnitude(QString planetName) const;
+	float getPlanetVMagnitude(QString planetName, bool withExtinction=false) const;
+
+	//! Get type for Solar system bodies from scripts
+	//! @param planetName the case in-sensistive English planet name.
+	//! @return a type of planet (planet, moon, asteroid, comet, plutoid)
+	QString getPlanetType(QString planetName) const;
 
 	//! Get distance to Solar system bodies from scripts
 	//! @param planetName the case in-sensistive English planet name.
