@@ -82,12 +82,12 @@ protected:
 	}
 	Vec3f getInfoColor(void) const
 	{
-		return StelSkyDrawer::indexToColor(s->bV);
+		return StelSkyDrawer::indexToColor(s->getBVIndex());
 	}
 	float getVMagnitude(const StelCore* core) const
 	{
 		Q_UNUSED(core);
-		return 0.001f*a->mag_min + s->mag*(0.001f*a->mag_range)/a->mag_steps;
+		return 0.001f*a->mag_min + s->getMag()*(0.001f*a->mag_range)/a->mag_steps;
 	}
 	float getBV(void) const {return s->getBV();}
 	QString getEnglishName(void) const {return QString();}
