@@ -15,12 +15,13 @@
  * 
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA  02110-1335, USA.
 */
  
 #ifndef _ADDREMOVELANDSCAPESDIALOG_HPP_
 #define _ADDREMOVELANDSCAPESDIALOG_HPP_
 
+#include "config.h"
 #include <QObject>
 #include <QStringList>
 
@@ -38,7 +39,7 @@ public:
 	virtual ~AddRemoveLandscapesDialog();
 
 public slots:
-	void languageChanged();
+	void retranslate();
 	//! This function overrides the non-virtual StelDialog::setVisible()
 	//! to allow the current landscape to be selected in the list of user
 	//! landscapes (if it is in the list) every time the dialog is displayed.
