@@ -17,6 +17,7 @@
  *   51 Franklin Street, Suite 500, Boston, MA  02110-1335, USA.           *
  ***************************************************************************/
 
+#include "config.h"
 #include "AngleSpinBox.hpp"
 #include "StelTranslator.hpp"
 #include <QDebug>
@@ -41,19 +42,19 @@ const QString AngleSpinBox::positivePrefix(PrefixType prefix)
 {
 	switch(prefix)
 	{
-	case NormalPlus:
-		return("+");
-		break;
-	case Longitude:
-		return(q_("E "));
-		break;
-	case Latitude:
-		return(q_("N "));
-		break;
-	case Normal:
-	default:
-		return("");
-		break;
+		case NormalPlus:
+			return("+");
+			break;
+		case Longitude:
+			return(q_("E "));
+			break;
+		case Latitude:
+			return(q_("N "));
+			break;
+		case Normal:
+		default:
+			return("");
+			break;
 	}
 }
 
@@ -61,19 +62,19 @@ const QString AngleSpinBox::negativePrefix(PrefixType prefix)
 {
 	switch(prefix)
 	{
-	case NormalPlus:
-		return(QLocale().negativeSign());
-		break;
-	case Longitude:
-		return(q_("W "));
-		break;
-	case Latitude:
-		return(q_("S "));
-		break;
-	case Normal:
-	default:
-		return(QLocale().negativeSign());
-		break;
+		case NormalPlus:
+			return(QLocale().negativeSign());
+			break;
+		case Longitude:
+			return(q_("W "));
+			break;
+		case Latitude:
+			return(q_("S "));
+			break;
+		case Normal:
+		default:
+			return(QLocale().negativeSign());
+			break;
 	}
 }
 
