@@ -38,7 +38,9 @@ DateTimeDialog::DateTimeDialog(QObject* parent) :
   day(0),
   hour(0),
   minute(0),
-  second(0)
+  second(0),
+  jd(0),
+  mjd(0)
 {
 	ui = new Ui_dateTimeDialogForm;
 }
@@ -52,13 +54,13 @@ DateTimeDialog::~DateTimeDialog()
 void DateTimeDialog::createDialogContent()
 {
 	ui->setupUi(dialog);
-	double jd = StelApp::getInstance().getCore()->getJDay();
+	double cjd = StelApp::getInstance().getCore()->getJDay();
 	// UTC -> local tz
 	// Add in a DeltaT correction. Divide DeltaT by 86400 to convert from seconds to days.
 	double deltaT = 0.;
 	if (StelApp::getInstance().getCore()->getCurrentLocation().planetName=="Earth")
-		deltaT = StelApp::getInstance().getCore()->getDeltaT(jd)/86400.;
-	setDateTime(jd + (StelApp::getInstance().getLocaleMgr().getGMTShift(jd)/24.0)-deltaT);
+		deltaT = StelApp::getInstance().getCore()->getDeltaT(cjd)/86400.;
+	setDateTime(cjd + (StelApp::getInstance().getLocaleMgr().getGMTShift(cjd)/24.0)-deltaT);
 
 	connect(&StelApp::getInstance(), SIGNAL(languageChanged()), this, SLOT(retranslate()));
 	connect(ui->closeStelWindow, SIGNAL(clicked()), this, SLOT(close()));
@@ -74,6 +76,8 @@ void DateTimeDialog::connectSpinnerEvents() const
 	connect(ui->spinner_hour, SIGNAL(valueChanged(int)), this, SLOT(hourChanged(int)));
 	connect(ui->spinner_minute, SIGNAL(valueChanged(int)), this, SLOT(minuteChanged(int)));
 	connect(ui->spinner_second, SIGNAL(valueChanged(int)), this, SLOT(secondChanged(int)));
+	connect(ui->spinner_jd, SIGNAL(valueChanged(double)), this, SLOT(jdChanged(double)));
+	connect(ui->spinner_mjd, SIGNAL(valueChanged(double)), this, SLOT(mjdChanged(double)));
 }
 
 void DateTimeDialog::disconnectSpinnerEvents()const
@@ -84,6 +88,8 @@ void DateTimeDialog::disconnectSpinnerEvents()const
 	disconnect(ui->spinner_hour, SIGNAL(valueChanged(int)), this, SLOT(hourChanged(int)));
 	disconnect(ui->spinner_minute, SIGNAL(valueChanged(int)), this, SLOT(minuteChanged(int)));
 	disconnect(ui->spinner_second, SIGNAL(valueChanged(int)), this, SLOT(secondChanged(int)));
+	disconnect(ui->spinner_jd, SIGNAL(valueChanged(double)), this, SLOT(jdChanged(double)));
+	disconnect(ui->spinner_mjd, SIGNAL(valueChanged(double)), this, SLOT(mjdChanged(double)));
 }
 
 
@@ -113,6 +119,22 @@ bool DateTimeDialog::valid(int y, int m, int d, int h, int min, int s)
 	return true;
 }
 
+bool DateTimeDialog::validJd(double jday)
+{
+	pushToWidgets();
+	// local tz -> UTC
+	StelApp::getInstance().getCore()->setJDay(jday-StelApp::getInstance().getLocaleMgr().getGMTShift(jday)/24.+StelApp::getInstance().getCore()->getDeltaT(jday)/86400.);
+	return true;
+}
+
+bool DateTimeDialog::validMjd(double mjday)
+{
+	pushToWidgets();
+	// local tz -> UTC
+	StelApp::getInstance().getCore()->setMJDay(mjday-StelApp::getInstance().getLocaleMgr().getGMTShift(mjday)/24.+StelApp::getInstance().getCore()->getDeltaT(mjday)/86400.);
+	return true;
+}
+
 void DateTimeDialog::retranslate()
 {
 	if (dialog) {
@@ -137,51 +159,72 @@ void DateTimeDialog::close()
 
 void DateTimeDialog::yearChanged(int newyear)
 {
-  if ( year != newyear ) {
-	valid( newyear, month, day, hour, minute, second );
-  }
+	if ( year != newyear )
+	{
+		valid( newyear, month, day, hour, minute, second );
+	}
 }
 void DateTimeDialog::monthChanged(int newmonth)
 {
-  if ( month != newmonth ) {
-	valid( year, newmonth, day, hour, minute, second );
-  }
+	if ( month != newmonth )
+	{
+		valid( year, newmonth, day, hour, minute, second );
+	}
 }
 void DateTimeDialog::dayChanged(int newday)
 {
-  if ( day != newday ) {
-	valid( year, month, newday, hour, minute, second );
-  }
+	if ( day != newday )
+	{
+		valid( year, month, newday, hour, minute, second );
+	}
 }
 void DateTimeDialog::hourChanged(int newhour)
 {
-  if ( hour != newhour ) {
-	valid( year, month, day, newhour, minute, second );
-  }
+	if ( hour != newhour )
+	{
+		valid( year, month, day, newhour, minute, second );
+	}
 }
 void DateTimeDialog::minuteChanged(int newminute)
 {
-  if ( minute != newminute ) {
-	valid( year, month, day, hour, newminute, second );
-  }
+	if ( minute != newminute )
+	{
+		valid( year, month, day, hour, newminute, second );
+	}
 }
 void DateTimeDialog::secondChanged(int newsecond)
 {
-  if ( second != newsecond ) {
-	valid( year, month, day, hour, minute, newsecond );
-  }
+	if ( second != newsecond )
+	{
+		valid( year, month, day, hour, minute, newsecond );
+	}
 }
+void DateTimeDialog::jdChanged(double njd)
+{
+	if ( jd != njd)
+	{
+		validJd(njd);
+	}
+}
+void DateTimeDialog::mjdChanged(double nmjd)
+{
+	if ( mjd != nmjd)
+	{
+		validMjd(nmjd);
+	}
+}
+
 
 double DateTimeDialog::newJd()
 {
-  double jd;  
-  StelUtils::getJDFromDate(&jd,year, month, day, hour, minute, second);
-  // Add in a DeltaT correction. Divide DeltaT by 86400 to convert from seconds to days.
-  double deltaT = 0.;
-  if (StelApp::getInstance().getCore()->getCurrentLocation().planetName=="Earth")
-	  deltaT = StelApp::getInstance().getCore()->getDeltaT(jd)/86400.;
-  jd -= (StelApp::getInstance().getLocaleMgr().getGMTShift(jd)/24.0-deltaT); // local tz -> UTC
-  return jd;
+	double cjd;
+	StelUtils::getJDFromDate(&cjd, year, month, day, hour, minute, second);
+	// Add in a DeltaT correction. Divide DeltaT by 86400 to convert from seconds to days.
+	double deltaT = 0.;
+	if (StelApp::getInstance().getCore()->getCurrentLocation().planetName=="Earth")
+		deltaT = StelApp::getInstance().getCore()->getDeltaT(cjd)/86400.;
+	cjd -= (StelApp::getInstance().getLocaleMgr().getGMTShift(cjd)/24.0-deltaT); // local tz -> UTC
+	return cjd;
 }
 
 void DateTimeDialog::pushToWidgets()
@@ -191,15 +234,21 @@ void DateTimeDialog::pushToWidgets()
 	ui->spinner_month->setValue(month);
 	ui->spinner_day->setValue(day);
 	ui->spinner_hour->setValue(hour);
-	if (!ui->spinner_minute->hasFocus()
-			|| (ui->spinner_minute->value() == -1)
-			|| (ui->spinner_minute->value() == 60)) {
-	  ui->spinner_minute->setValue(minute);
+	if (!ui->spinner_minute->hasFocus() || (ui->spinner_minute->value() == -1) || (ui->spinner_minute->value() == 60))
+	{
+		ui->spinner_minute->setValue(minute);
 	}
-	if (!ui->spinner_second->hasFocus()
-			|| (ui->spinner_second->value() == -1)
-			|| (ui->spinner_second->value() == 60)) {
-	  ui->spinner_second->setValue(second);
+	if (!ui->spinner_second->hasFocus() || (ui->spinner_second->value() == -1) || (ui->spinner_second->value() == 60))
+	{
+		ui->spinner_second->setValue(second);
+	}
+	if (!ui->spinner_jd->hasFocus())
+	{
+		ui->spinner_jd->setValue(jd);
+	}
+	if (!ui->spinner_mjd->hasFocus())
+	{
+		ui->spinner_mjd->setValue(mjd);
 	}
 	connectSpinnerEvents();
 }
@@ -217,6 +266,8 @@ void DateTimeDialog::setDateTime(double newJd)
 		newJd += (StelApp::getInstance().getLocaleMgr().getGMTShift(newJd)/24.0-deltaT); // UTC -> local tz
 		StelUtils::getDateFromJulianDay(newJd, &year, &month, &day);
 		StelUtils::getTimeFromJulianDay(newJd, &hour, &minute, &second);
+		jd = newJd;
+		mjd = newJd-2400000.5;
 		pushToWidgets();
 	}
 }
