@@ -82,6 +82,7 @@ private slots:
 	void updateFromProgram(const StelLocation& location);
 	
 	//! Called when the map is clicked.
+	//! GZ_New: create new list for places nearby and feed into location list box.
 	void setPositionFromMap(double longitude, double latitude);
 	
 	//! Called when the user activates an item from the locations list.
@@ -97,9 +98,18 @@ private slots:
 	
 	//! Called when the user clicks on the delete button
 	void deleteCurrentLocationFromList();
+
+	//! filter city list to show entries from single country only
+	void filterSitesByCountry();
+
+	//! reset city list to complete list (may have been reduced to picked list)
+	void resetCompleteList();
+
+	//! called when the user wants get location from network
+	void ipQueryLocation(bool state);
 	
 	//! Called when the user wants to use the current location as default
-	void setDefaultLocation();
+	void setDefaultLocation(bool state);
 	
 private:
 	QString lastPlanet;
