@@ -291,6 +291,11 @@ void ShortcutsDialog::createDialogContent()
 	ui->shortcutsTreeView->header()->setSectionsMovable(false);
 	ui->shortcutsTreeView->sortByColumn(0, Qt::AscendingOrder);
 	
+	//Kinetic scrolling for tablet pc and pc
+	QList<QWidget *> addscroll;
+	addscroll << ui->shortcutsTreeView;
+	installKineticScrolling(addscroll);
+
 	connect(&StelApp::getInstance(), SIGNAL(languageChanged()), this, SLOT(retranslate()));
 	connect(ui->shortcutsTreeView->selectionModel(),
 	        SIGNAL(currentChanged(QModelIndex,QModelIndex)),
@@ -361,7 +366,8 @@ QStandardItem* ShortcutsDialog::updateGroup(const QString& group)
 	// setup bold font for group lines
 	QFont rootFont = groupItem->font();
 	rootFont.setBold(true);
-	rootFont.setPixelSize(14);
+	// Font size is 14
+	rootFont.setPixelSize(StelApp::getInstance().getBaseFontSize()+1);
 	groupItem->setFont(rootFont);
 	if (isNew)
 		mainModel->appendRow(groupItem);
