@@ -20,6 +20,7 @@
 #ifndef _SKYGUI_HPP_
 #define _SKYGUI_HPP_
 
+#include "config.h"
 #include "StelStyle.hpp"
 #include "StelObject.hpp"
 
@@ -27,12 +28,11 @@
 #include <QGraphicsWidget>
 
 class QGraphicsSceneMouseEvent;
-class QAction;
 class QGraphicsTextItem;
 class QTimeLine;
 class StelButton;
 class BottomStelBar;
-
+class StelProgressController;
 
 //! The informations about the currently selected object
 class InfoPanel : public QGraphicsTextItem
@@ -62,11 +62,14 @@ public:
 	//! Add a new progress bar in the lower right corner of the screen.
 	//! When the progress bar is deleted with removeProgressBar() the layout is automatically rearranged.
 	//! @return a pointer to the progress bar
-	class QProgressBar* addProgressBar();
+	void addProgressBar(StelProgressController*);
 	
 	void init(class StelGui* stelGui);
 	
 	virtual void paint(QPainter*, const QStyleOptionGraphicsItem*, QWidget* = 0);
+
+	int getSkyGuiWidth() const;
+	int getSkyGuiHeight() const;
 	
 protected:
 	virtual void resizeEvent(QGraphicsSceneResizeEvent* event);
