@@ -106,6 +106,7 @@ StelGui::StelGui()
 	, flagShowNebulaBackgroundButton(false)
 	, btShowNebulaeBackground(NULL)
 	, initDone(false)
+	, flagShowDecimalDegrees(false)
 {
 	// QPixmapCache::setCacheLimit(30000); ?
 }
@@ -358,6 +359,8 @@ void StelGui::init(QGraphicsWidget *atopLevelGraphicsWidget)
 	setFlagShowFlipButtons(conf->value("gui/flag_show_flip_buttons", false).toBool());
 	setFlagShowNebulaBackgroundButton(conf->value("gui/flag_show_nebulae_background_button", false).toBool());
 
+	setFlagShowDecimalDegrees(conf->value("gui/flag_show_decimal_degrees", false).toBool());
+
 	///////////////////////////////////////////////////////////////////////
 	// Create the main base widget
 	skyGui->init(this);
@@ -635,6 +638,11 @@ void StelGui::setFlagShowNebulaBackgroundButton(bool b)
 	flagShowNebulaBackgroundButton = b;
 }
 
+void StelGui::setFlagShowDecimalDegrees(bool b)
+{
+	flagShowDecimalDegrees=b;
+}
+
 void StelGui::setVisible(bool b)
 {
 	skyGui->setVisible(b);
@@ -713,6 +721,11 @@ bool StelGui::getFlagShowNebulaBackgroundButton() const
 	return flagShowNebulaBackgroundButton;
 }
 
+bool StelGui::getFlagShowDecimalDegrees() const
+{
+	return flagShowDecimalDegrees;
+}
+
 bool StelGui::initComplete(void) const
 {
 	return initDone;
