@@ -72,7 +72,7 @@ public:
 	//! Load a Qt style sheet to define the widgets style
 	void loadStyle(const QString& fileName);
 	
-	//! Get the button bar at the bottom of the screensetDateTime
+	//! Get the button bar at the bottom of the screen
 	BottomStelBar* getButtonBar() const;
 	
 	//! Get the button bar of the left of the screen
@@ -88,7 +88,9 @@ public:
 	//! Get whether the button toggling nebulae background is visible
 	bool getFlagShowNebulaBackgroundButton() const;
 
-	//! returns true if the gui has complted init process.
+	bool getFlagShowDecimalDegrees() const;
+
+	//! returns true if the gui has completed init process.
 	bool initComplete(void) const;
 
 #ifdef ENABLE_SCRIPT_CONSOLE
@@ -114,6 +116,8 @@ public slots:
 	//! Define whether the button toggling nebulae background should be visible
 	void setFlagShowNebulaBackgroundButton(bool b);
 
+	void setFlagShowDecimalDegrees(bool b);
+
 	//! Get the auto-hide status of the horizontal toolbar.
 	bool getAutoHideHorizontalButtonBar() const;
 	//! Set the auto-hide status of the horizontal toolbar.
@@ -193,6 +197,8 @@ private:
 
 	bool initDone;
 
+	bool flagShowDecimalDegrees;
+
 	QSizeF savedProgressBarSize;
 
 	// Currently used StelStyle
