@@ -19,6 +19,7 @@
  */
 
 
+#include "StelScriptOutput.hpp"
 #include "StelScriptMgr.hpp"
 #include "StelMainScriptAPI.hpp"
 #include "StelModuleMgr.hpp"
@@ -423,6 +424,12 @@ void StelScriptMgr::debug(const QString& msg)
 	emit(scriptDebug(msg));
 }
 
+void StelScriptMgr::output(const QString &msg)
+{
+	StelScriptOutput::writeLog(msg);
+	emit(scriptOutput(msg));
+}
+
 void StelScriptMgr::scriptEnded()
 {
 	if (engine.hasUncaughtException())
