@@ -14,19 +14,17 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA  02110-1335, USA.
  */
 
 #ifndef _TESTDELTAT_HPP_
 #define _TESTDELTAT_HPP_
 
 #include <QObject>
-#include <QtTest>
+#include <QTest>
 #include <QVector>
 #include <QString>
 
-#include "StelUtils.hpp"
-
 class TestDeltaT : public QObject
 {
 Q_OBJECT
