@@ -185,11 +185,45 @@ class Translations
 		N_("moon");
 		// TRANSLATORS: Type of object
 		N_("plutoid");
+		// TRANSLATORS: Type of objects (for "Lists" in the search tool)
+		N_("Planets");
+		// TRANSLATORS: Type of objects (for "Lists" in the search tool)
+		N_("Comets");
+		// TRANSLATORS: Type of objects (for "Lists" in the search tool)
+		N_("Asteroids");
+		// TRANSLATORS: Type of objects (for "Lists" in the search tool)
+		N_("Moons");
+		// TRANSLATORS: Type of objects (for "Lists" in the search tool)
+		N_("Plutoids");
 
+		// =====================================================================
+		// List of deep-sky objects types
+		// TRANSLATORS: Type of objects (for "Lists" in the search tool)
+		N_("Bright galaxies");
+		// TRANSLATORS: Type of objects (for "Lists" in the search tool)
+		N_("Open star clusters");
+		// TRANSLATORS: Type of objects (for "Lists" in the search tool)
+		N_("Globular star clusters");
+		// TRANSLATORS: Type of objects (for "Lists" in the search tool)
+		N_("Nebulae");
+		// TRANSLATORS: Type of objects (for "Lists" in the search tool)
+		N_("Planetary nebulae");
+		// TRANSLATORS: Type of objects (for "Lists" in the search tool)
+		N_("Dark nebulae");
+		// TRANSLATORS: Type of objects (for "Lists" in the search tool)
+		N_("Irregular galaxies");
+		// TRANSLATORS: Type of objects (for "Lists" in the search tool)
+		N_("Clusters associated with nebulosity");
+		// TRANSLATORS: Catalogue of objects (for "Lists" in the search tool)
+		N_("Messier Catalogue");
+		// TRANSLATORS: Catalogue of objects (for "Lists" in the search tool)
+		N_("Caldwell Catalogue");
+		
 		// =====================================================================
 		// Constellation cultures
 		N_("Arabic");
 		N_("Aztec");
+		N_("Boorong");
 		N_("Chinese");
 		N_("Egyptian");
 		N_("Inuit");
@@ -197,6 +231,7 @@ class Translations
 		N_("Korean");
 		N_("Lakota");
 		N_("Maori");
+		N_("Mongolian");
 		N_("Navajo");
 		N_("Norse");
 		N_("Polynesian");
